@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -35,12 +35,10 @@
 import numpy
 from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
 from tvb.core.adapters.abcuploader import ABCUploader, ABCUploaderForm
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.adapters.exceptions import LaunchException
 from tvb.core.neotraits.uploader_view_model import UploaderViewModel
-from tvb.core.neotraits.view_model import Str, Attr
+from tvb.core.neotraits.view_model import Str
 from tvb.core.neotraits.forms import TraitUploadField, SelectField
-from tvb.core.neocom import h5
 from tvb.datatypes.connectivity import Connectivity
 
 NORMALIZATION_OPTIONS = {'Region (node)': 'region', 'Absolute (max weight)': 'tract'}
@@ -65,8 +63,7 @@ class ZIPConnectivityImporterForm(ABCUploaderForm):
         super(ZIPConnectivityImporterForm, self).__init__()
 
         self.uploaded = TraitUploadField(ZIPConnectivityImporterModel.uploaded, '.zip', 'uploaded')
-        self.normalization = SelectField(ZIPConnectivityImporterModel.normalization, name='normalization',
-                                         choices=NORMALIZATION_OPTIONS)
+        self.normalization = SelectField(ZIPConnectivityImporterModel.normalization, name='normalization')
 
     @staticmethod
     def get_view_model():
@@ -116,7 +113,7 @@ class ZIPConnectivityImporter(ABCUploader):
         if view_model.uploaded is None:
             raise LaunchException("Please select ZIP file which contains data to import")
 
-        files = FilesHelper().unpack_zip(view_model.uploaded, self.storage_path)
+        files = self.storage_interface.unpack_zip(view_model.uploaded, self.get_storage_path())
 
         weights_matrix = None
         centres = None
@@ -146,64 +143,22 @@ class ZIPConnectivityImporter(ABCUploader):
                 hemisphere_vector = self.read_list_data(file_name, dtype=numpy.bool)
 
         # Clean remaining text-files.
-        FilesHelper.remove_files(files, True)
+        self.storage_interface.remove_files(files, True)
 
         result = Connectivity()
 
-        # Fill positions
-        if centres is None:
-            raise Exception("Region centres are required for Connectivity Regions! "
-                            "We expect a file that contains *centres* inside the uploaded ZIP.")
+        # Set attributes
         expected_number_of_nodes = len(centres)
-        if expected_number_of_nodes < 2:
-            raise Exception("A connectivity with at least 2 nodes is expected")
-        result.centres = centres
-        if labels_vector is not None:
-            result.region_labels = labels_vector
-
-        # Fill and check weights
-        if weights_matrix is not None:
-            if weights_matrix.shape != (expected_number_of_nodes, expected_number_of_nodes):
-                raise Exception("Unexpected shape for weights matrix! "
-                                "Should be %d x %d " % (expected_number_of_nodes, expected_number_of_nodes))
-            result.weights = weights_matrix
-            if view_model.normalization:
-                result.weights = result.scaled_weights(view_model.normalization)
-
-        # Fill and check tracts. Allow empty files for tracts, they will be computed by tvb-library.
-        if tract_matrix is not None:
-            if tract_matrix.size != 0:
-                if numpy.any([x < 0 for x in tract_matrix.flatten()]):
-                    raise Exception("Negative values are not accepted in tracts matrix! "
-                                    "Please check your file, and use values >= 0")
-                if tract_matrix.shape != (expected_number_of_nodes, expected_number_of_nodes):
-                    raise Exception("Unexpected shape for tracts matrix! "
-                                    "Should be %d x %d " % (expected_number_of_nodes, expected_number_of_nodes))
-            result.tract_lengths = tract_matrix
-
-        if orientation is not None:
-            if len(orientation) != expected_number_of_nodes:
-                raise Exception("Invalid size for vector orientation. "
-                                "Expected the same as region-centers number %d" % expected_number_of_nodes)
-            result.orientations = orientation
-
-        if areas is not None:
-            if len(areas) != expected_number_of_nodes:
-                raise Exception("Invalid size for vector areas. "
-                                "Expected the same as region-centers number %d" % expected_number_of_nodes)
-            result.areas = areas
-
-        if cortical_vector is not None:
-            if len(cortical_vector) != expected_number_of_nodes:
-                raise Exception("Invalid size for vector cortical. "
-                                "Expected the same as region-centers number %d" % expected_number_of_nodes)
-            result.cortical = cortical_vector
-
-        if hemisphere_vector is not None:
-            if len(hemisphere_vector) != expected_number_of_nodes:
-                raise Exception("Invalid size for vector hemispheres. "
-                                "Expected the same as region-centers number %d" % expected_number_of_nodes)
-            result.hemispheres = hemisphere_vector
+        result.set_centres(centres, expected_number_of_nodes)
+        result.set_region_labels(labels_vector)
+        result.set_weights(weights_matrix, expected_number_of_nodes)
+        if view_model.normalization:
+            result.weights = result.scaled_weights(view_model.normalization)
+        result.set_tract_lengths(tract_matrix, expected_number_of_nodes)
+        result.set_orientations(orientation, expected_number_of_nodes)
+        result.set_areas(areas, expected_number_of_nodes)
+        result.set_cortical(cortical_vector, expected_number_of_nodes)
+        result.set_hemispheres(hemisphere_vector, expected_number_of_nodes)
 
         result.configure()
-        return h5.store_complete(result, self.storage_path)
+        return self.store_complete(result)
