@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -34,7 +34,6 @@
 
 import json
 import uuid
-import numpy
 from abc import ABCMeta
 from six import add_metaclass
 from tvb.adapters.visualizers.time_series import ABCSpaceDisplayer
@@ -45,6 +44,7 @@ from tvb.adapters.datatypes.h5.surface_h5 import SPLIT_PICK_MAX_TRIANGLE, KEY_VE
 from tvb.basic.logger.builder import get_logger
 from tvb.core.adapters.abcadapter import ABCAdapterForm
 from tvb.core.adapters.abcdisplayer import URLGenerator
+from tvb.core.adapters.exceptions import LaunchException
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.entities.load import try_get_last_datatype
 from tvb.core.entities.storage import dao
@@ -53,12 +53,12 @@ from tvb.core.neocom import h5
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr
 from tvb.datatypes.graph import ConnectivityMeasure
 from tvb.datatypes.region_mapping import RegionMapping
-from tvb.datatypes.surfaces import Surface, FACE
+from tvb.datatypes.surfaces import Surface, SurfaceTypesEnum
 
 LOG = get_logger(__name__)
 
 
-def ensure_shell_surface(project_id, shell_surface=None, preferred_type=FACE):
+def ensure_shell_surface(project_id, shell_surface=None, preferred_type=SurfaceTypesEnum.FACE_SURFACE.value):
     filter = FilterChain(fields=[FilterChain.datatype + '.surface_type'], operations=["=="],
                          values=[preferred_type])
     if shell_surface is None:
@@ -209,13 +209,10 @@ class ABCSurfaceDisplayer(ABCSpaceDisplayer):
         boundary_lines = []
         boundary_normals = []
 
-        surface_index = self.load_entity_by_gid(surface_gid)
-        rm_index = self.load_entity_by_gid(region_mapping_gid)
-
-        with h5.h5_file_for_index(rm_index) as rm_h5:
+        with h5.h5_file_for_gid(region_mapping_gid) as rm_h5:
             array_data = rm_h5.array_data[:]
 
-        with h5.h5_file_for_index(surface_index) as surface_h5:
+        with h5.h5_file_for_gid(surface_gid) as surface_h5:
             for slice_idx in range(surface_h5.get_number_of_split_slices()):
                 # Generate the boundaries sliced for the off case where we might overflow the buffer capacity
                 slice_triangles = surface_h5.get_triangles_slice(slice_idx)
@@ -253,7 +250,7 @@ class ABCSurfaceDisplayer(ABCSpaceDisplayer):
                 boundary_vertices.append(processed_vertices)
                 boundary_lines.append(processed_triangles)
                 boundary_normals.append(processed_normals)
-            return numpy.array([boundary_vertices, boundary_lines, boundary_normals]).tolist()
+            return [boundary_vertices, boundary_lines, boundary_normals]
 
     @staticmethod
     def _process_triangle(triangle, reg_idx1, reg_idx2, dangling_idx, indices_offset,
@@ -428,21 +425,14 @@ class SurfaceViewer(ABCSurfaceDisplayer):
 
         surface_h5.close()
 
-        params['shelfObject'] = None
+        params['shellObject'] = None
 
         shell_surface_index = None
         if view_model.shell_surface:
             shell_surface_index = self.load_entity_by_gid(view_model.shell_surface)
 
         shell_surface = ensure_shell_surface(self.current_project_id, shell_surface_index)
-
-        if shell_surface:
-            shell_h5 = h5.h5_file_for_index(shell_surface)
-            assert isinstance(shell_h5, SurfaceH5)
-            shell_vertices, shell_normals, _, shell_triangles, _ = SurfaceURLGenerator.get_urls_for_rendering(shell_h5)
-            params['shelfObject'] = json.dumps([shell_vertices, shell_normals, shell_triangles])
-            shell_h5.close()
-
+        params['shellObject'] = self.prepare_shell_surface_params(shell_surface, SurfaceURLGenerator)
         return self.build_display_result("surface/surface_view", params,
                                          pages={"controlPage": "surface/surface_viewer_controls"})
 
@@ -551,6 +541,8 @@ class ConnectivityMeasureOnSurfaceViewer(SurfaceViewer):
             if region_maps:
                 region_map_index = region_maps[0]
 
+        if region_map_index is None:
+            raise LaunchException("Can not launch this viewer without a compatible RegionMapping entity in the current project!")
         surface_gid = region_map_index.fk_surface_gid
         surface_viewer_model = SurfaceViewerModel(surface=surface_gid,
                                                   region_map=region_map_index.gid,
