@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -38,6 +38,7 @@ A Javascript displayer for time series, using SVG.
 import json
 from abc import ABCMeta
 from six import add_metaclass
+
 from tvb.adapters.datatypes.h5.time_series_h5 import TimeSeriesRegionH5, TimeSeriesSensorsH5, TimeSeriesH5
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.adapters.abcadapter import ABCAdapterForm
@@ -46,6 +47,7 @@ from tvb.adapters.datatypes.db.time_series import TimeSeriesIndex
 from tvb.core.neotraits.forms import TraitDataTypeSelectField
 from tvb.core.neocom import h5
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr
+from tvb.core.utils import TVBJSONEncoder
 from tvb.datatypes.connectivity import Connectivity
 from tvb.datatypes.time_series import TimeSeries
 
@@ -109,8 +111,7 @@ class ABCSpaceDisplayer(ABCDisplayer):
         """
         if isinstance(ts_h5, TimeSeriesSensorsH5):
             sensors_gid = ts_h5.sensors.load()
-            sensors_idx = self.load_entity_by_gid(sensors_gid)
-            with h5.h5_file_for_index(sensors_idx) as sensors_h5:
+            with h5.h5_file_for_gid(sensors_gid) as sensors_h5:
                 labels = sensors_h5.labels.load()
                 # TODO uncomment this when the UI component will be able to scale for many groups
                 # if isinstance(ts_h5, TimeSeriesSEEGH5):
@@ -133,16 +134,15 @@ class ABCSpaceDisplayer(ABCDisplayer):
             connectivity_gid = ts_h5.connectivity.load()
             if connectivity_gid is None:
                 return []
-            conn_idx = self.load_entity_by_gid(connectivity_gid)
-            with h5.h5_file_for_index(conn_idx) as conn_h5:
+
+            with h5.h5_file_for_gid(connectivity_gid) as conn_h5:
                 return list(conn_h5.region_labels.load())
 
         if isinstance(ts_h5, TimeSeriesSensorsH5):
             sensors_gid = ts_h5.sensors.load()
             if sensors_gid is None:
                 return []
-            sensors_idx = self.load_entity_by_gid(sensors_gid)
-            with h5.h5_file_for_index(sensors_idx) as sensors_h5:
+            with h5.h5_file_for_gid(sensors_gid) as sensors_h5:
                 return list(sensors_h5.labels.load())
 
         return ts_h5.get_space_labels()
@@ -167,7 +167,7 @@ class TimeSeriesDisplay(ABCSpaceDisplayer):
         h5_file = h5.h5_file_for_index(time_series_index)
         assert isinstance(h5_file, TimeSeriesH5)
         shape = list(h5_file.read_data_shape())
-        ts = h5_file.storage_manager.get_data('time')
+        ts = h5_file.time.load()
         state_variables = time_series_index.get_labels_for_dimension(1)
         labels = self.get_space_labels(h5_file)
 
@@ -182,7 +182,7 @@ class TimeSeriesDisplay(ABCSpaceDisplayer):
                 labels.append("Node-" + str(n))
 
         pars = {'baseURL': URLGenerator.build_base_h5_url(time_series_index.gid),
-                'labels': labels, 'labels_json': json.dumps(labels),
+                'labels': labels, 'labels_json': json.dumps(labels, cls=TVBJSONEncoder),
                 'ts_title': time_series_index.title, 'preview': preview, 'figsize': figsize,
                 'shape': repr(shape), 't0': ts[0],
                 'dt': ts[1] - ts[0] if len(ts) > 1 else 1,
@@ -197,7 +197,3 @@ class TimeSeriesDisplay(ABCSpaceDisplayer):
         # type: (TimeSeriesModel) -> dict
         """Construct data for visualization and launch it."""
         return self._launch(view_model, None)
-
-    def generate_preview(self, view_model, figure_size=None):
-        # type: (TimeSeriesModel, (int, int)) -> dict
-        return self._launch(view_model, figsize=figure_size, preview=True)
