@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -39,16 +39,18 @@ Backend-side for TS Visualizer of TS Volume DataTypes.
 """
 
 import json
+
 import numpy
-from tvb.adapters.visualizers.region_volume_mapping import _MappedArrayVolumeBase
-from tvb.adapters.datatypes.h5.time_series_h5 import TimeSeriesVolumeH5, TimeSeriesRegionH5
 from tvb.adapters.datatypes.db.structural import StructuralMRIIndex
 from tvb.adapters.datatypes.db.time_series import TimeSeriesIndex
-from tvb.core.adapters.abcdisplayer import URLGenerator
+from tvb.adapters.datatypes.h5.time_series_h5 import TimeSeriesVolumeH5, TimeSeriesRegionH5
+from tvb.adapters.visualizers.region_volume_mapping import _MappedArrayVolumeBase, MappedArrayVolumeVisualizer
 from tvb.core.adapters.abcadapter import ABCAdapterForm
-from tvb.core.adapters.arguments_serialisation import preprocess_space_parameters, postprocess_voxel_ts
+from tvb.core.adapters.abcdisplayer import URLGenerator
+from tvb.core.adapters.arguments_serialisation import postprocess_voxel_ts
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.entities.storage import dao
+from tvb.core.neocom import h5
 from tvb.core.neotraits.forms import TraitDataTypeSelectField
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr
 from tvb.core.utils import prepare_time_slice
@@ -109,30 +111,23 @@ class TimeSeriesVolumeVisualiser(_MappedArrayVolumeBase):
     def launch(self, view_model):
         # type: (TimeSeriesVolumeVisualiserModel) -> dict
 
-        url_volume_data = URLGenerator.build_url(self.stored_adapter.id, 'get_volume_view', view_model.time_series, '')
+        url_volume_data = URLGenerator.build_url(MappedArrayVolumeVisualizer.stored_adapter.id, 'get_volume_view', view_model.time_series, '')
         url_timeseries_data = URLGenerator.build_url(self.stored_adapter.id, 'get_voxel_time_series',
                                                      view_model.time_series, '')
 
-        ts_h5_class, ts_h5_path = self._load_h5_of_gid(view_model.time_series.hex)
-        ts_h5 = ts_h5_class(ts_h5_path)
+        ts_index = self.load_entity_by_gid(view_model.time_series)
+        ts_h5 = h5.h5_file_for_index(ts_index)
         min_value, max_value = ts_h5.get_min_max_values()
 
-        ts_index = self.load_entity_by_gid(view_model.time_series)
-
         if isinstance(ts_h5, TimeSeriesVolumeH5):
-            volume_h5_class, volume_h5_path = self._load_h5_of_gid(ts_h5.volume.load())
-            volume_h5 = volume_h5_class(volume_h5_path)
             volume_shape = ts_h5.data.shape
+            volume = self.load_traited_by_gid(ts_h5.volume.load())
         else:
-            rmv_index = self.load_entity_by_gid(ts_h5.region_mapping_volume.load())
-            rmv_h5_class, rmv_h5_path = self._load_h5_of_gid(rmv_index.gid)
-            rmv_h5 = rmv_h5_class(rmv_h5_path)
-            volume_index = self.load_entity_by_gid(rmv_h5.volume.load())
-            volume_h5_class, volume_h5_path = self._load_h5_of_gid(volume_index.gid)
-            volume_h5 = volume_h5_class(volume_h5_path)
+            rm_index = self.load_entity_by_gid(ts_h5.region_mapping_volume.load())
+            volume = self.load_traited_by_gid(rm_index.fk_volume_gid)
+            rmv = self.load_traited_by_gid(ts_h5.region_mapping_volume.load())
             volume_shape = [ts_h5.data.shape[0]]
-            volume_shape.extend(rmv_h5.array_data.shape)
-            rmv_h5.close()
+            volume_shape.extend(rmv.array_data.shape)
 
         background_index = None
         if view_model.background:
@@ -148,14 +143,13 @@ class TimeSeriesVolumeVisualiser(_MappedArrayVolumeBase):
                       samplePeriod=ts_h5.sample_period.load(),
                       samplePeriodUnit=ts_h5.sample_period_unit.load(),
                       volumeShape=json.dumps(volume_shape),
-                      volumeOrigin=json.dumps(volume_h5.origin.load().tolist()),
-                      voxelUnit=volume_h5.voxel_unit.load(),
-                      voxelSize=json.dumps(volume_h5.voxel_size.load().tolist()))
+                      volumeOrigin=json.dumps(volume.origin.tolist()),
+                      voxelUnit=volume.voxel_unit,
+                      voxelSize=json.dumps(volume.voxel_size.tolist()))
 
         params.update(self.ensure_background(background_index))
-
-        volume_h5.close()
         ts_h5.close()
+
         return self.build_display_result("time_series_volume/view", params,
                                          pages=dict(controlPage="time_series_volume/controls"))
 
@@ -166,10 +160,8 @@ class TimeSeriesVolumeVisualiser(_MappedArrayVolumeBase):
         if background_index is None:
             return _MappedArrayVolumeBase.compute_background_params()
 
-        background_class, background_path = self._load_h5_of_gid(background_index.gid)
-        background_h5 = background_class(background_path)
-        min_value, max_value = background_h5.get_min_max_values()
-        background_h5.close()
+        with h5.h5_file_for_index(background_index) as background_h5:
+            min_value, max_value = background_h5.get_min_max_values()
 
         url_volume_data = URLGenerator.build_url(self.stored_adapter.id, 'get_volume_view', background_index.gid, '')
         return _MappedArrayVolumeBase.compute_background_params(min_value, max_value, url_volume_data)
@@ -186,24 +178,14 @@ class TimeSeriesVolumeVisualiser(_MappedArrayVolumeBase):
                 The main part will be a vector with all the values over time from the x,y,z coordinates.
         """
 
-        ts_h5_class, ts_h5_path = self._load_h5_of_gid(entity_gid)
+        with h5.h5_file_for_gid(entity_gid) as ts_h5:
+            if isinstance(ts_h5, TimeSeriesRegionH5):
+                return self.prepare_view_region(ts_h5, **kwargs)
 
-        with ts_h5_class(ts_h5_path) as ts_h5:
-            if ts_h5_class is TimeSeriesRegionH5:
-                return self._get_voxel_time_series_region(ts_h5, **kwargs)
+            data = ts_h5.get_voxel_time_series(**kwargs)
+        return data
 
-            return ts_h5.get_voxel_time_series(**kwargs)
-
-    def _get_voxel_time_series_region(self, ts_h5, x, y, z, var=0, mode=0):
-        region_mapping_volume_gid = ts_h5.region_mapping_volume.load()
-        if region_mapping_volume_gid is None:
-            raise Exception("Invalid method called for TS without Volume Mapping!")
-
-        volume_rm_h5_class, volume_rm_h5_path = self._load_h5_of_gid(region_mapping_volume_gid.hex)
-        volume_rm_h5 = volume_rm_h5_class(volume_rm_h5_path)
-
-        volume_rm_shape = volume_rm_h5.array_data.shape
-        x, y, z = preprocess_space_parameters(x, y, z, volume_rm_shape[0], volume_rm_shape[1], volume_rm_shape[2])
+    def get_view_region(self, ts_h5, volume_rm_h5, from_idx, to_idx, x, y, z, var=0, mode=0):
         idx_slices = slice(x, x + 1), slice(y, y + 1), slice(z, z + 1)
 
         idx = int(volume_rm_h5.array_data[idx_slices])
@@ -213,9 +195,8 @@ class TimeSeriesVolumeVisualiser(_MappedArrayVolumeBase):
         voxel_slices = prepare_time_slice(time_length), slice(var, var + 1), slice(idx, idx + 1), slice(mode, mode + 1)
 
         connectivity_gid = volume_rm_h5.connectivity.load()
-        connectivity_h5_class, connectivity_h5_path = self._load_h5_of_gid(connectivity_gid.hex)
-        connectivity_h5 = connectivity_h5_class(connectivity_h5_path)
-        label = connectivity_h5.region_labels.load()[idx]
+        with h5.h5_file_for_gid(connectivity_gid) as connectivity_h5:
+            label = connectivity_h5.region_labels.load()[idx]
 
         background, back_min, back_max = None, None, None
         if idx < 0:
@@ -223,8 +204,5 @@ class TimeSeriesVolumeVisualiser(_MappedArrayVolumeBase):
             background = numpy.ones((time_length, 1)) * ts_h5.out_of_range(back_min)
             label = 'background'
 
-        volume_rm_h5.close()
-        connectivity_h5.close()
-
         result = postprocess_voxel_ts(ts_h5, voxel_slices, background, back_min, back_max, label)
         return result
