@@ -36,7 +36,6 @@ TVB global configurations are predefined/read from here, for working with Framew
 
 import os
 import sys
-
 from tvb.basic.config import stored
 from tvb.basic.config.profile_settings import BaseSettingsProfile
 from tvb.basic.config.settings import DBSettings
@@ -103,7 +102,8 @@ class TestSQLiteProfile(WebSettingsProfile):
         super(TestSQLiteProfile, self).__init__()
 
         self.web.RENDER_HTML = False
-        self.MAX_THREADS_NUMBER = self.manager.get_attribute(stored.KEY_MAX_THREAD_NR, 2, int)
+        # NOTE: overwriting MAX_THREADS_NUMBER won't work in a test profile, as it needs a restart
+        # self.MAX_THREADS_NUMBER = self.manager.get_attribute(stored.KEY_MAX_THREAD_NR, 2, int)
 
         self.TVB_STORAGE = self.manager.get_attribute(stored.KEY_STORAGE, self.DEFAULT_STORAGE, str)
         # For tests we will place logs in workspace (current folder), to have them visible from Hudson.
@@ -124,9 +124,6 @@ class TestSQLiteProfile(WebSettingsProfile):
     def initialize_profile(self, change_logger_in_dev=False):
         super(TestSQLiteProfile, self).initialize_profile(change_logger_in_dev=change_logger_in_dev)
 
-        from tvb.core.utils import get_matlab_executable
-        self.MATLAB_EXECUTABLE = get_matlab_executable()
-
     def initialize_for_deployment(self):
         """
         This profile will not be used in deployment, so we try to avoid problems due to too much initialization
