@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -33,10 +33,9 @@
 """
 
 import os
-from uuid import UUID
-
+import numpy
 from tvb.core.entities.load import load_entity_by_gid
-from tvb.core.neotraits.forms import TraitDataTypeSelectField, TraitUploadField
+from tvb.core.neotraits.forms import TraitDataTypeSelectField, TraitUploadField, UserSessionStrField
 
 
 def _review_operation_inputs_for_adapter_model(form_fields, form_model, view_model):
@@ -48,25 +47,30 @@ def _review_operation_inputs_for_adapter_model(form_fields, form_model, view_mod
         if not hasattr(view_model, field.name):
             continue
         attr_vm = getattr(view_model, field.name)
-        if type(field) == TraitUploadField:
+        if attr_vm and type(field) == TraitUploadField:
             attr_vm = os.path.basename(attr_vm)
+        if attr_vm and type(field) == UserSessionStrField:
+            # Don't show UserSession actual value, as these might contain a secret, instead show the env Variable
+            changed_attr[field.label] = "SECRET ${%s}" % field.name
+            continue
 
         if isinstance(field, TraitDataTypeSelectField):
             data_type = None
             if attr_vm:
-                data_type = None
-                if isinstance(attr_vm, UUID) or isinstance(attr_vm, str):
-                    data_type = load_entity_by_gid(attr_vm)
-                if hasattr(attr_vm, field.name + '_gid'):
-                    dt_gid = getattr(attr_vm, field.name + '_gid')
-                    data_type = load_entity_by_gid(dt_gid)
+                data_type = load_entity_by_gid(attr_vm)
                 changed_attr[field.label] = data_type.display_name if data_type else "None"
             inputs_datatypes.append(data_type)
         else:
             attr_default = None
             if hasattr(form_model, field.name):
                 attr_default = getattr(form_model, field.name)
-            if attr_vm != attr_default:
+
+            if isinstance(attr_vm, numpy.ndarray):
+                check_for_changed = attr_vm.size != 0
+            else:
+                check_for_changed = attr_vm != attr_default
+
+            if check_for_changed:
                 if isinstance(attr_vm, float) or isinstance(attr_vm, int) or isinstance(attr_vm, str):
                     changed_attr[field.label] = attr_vm
                 elif isinstance(attr_vm, tuple) or isinstance(attr_vm, list):
