@@ -34,6 +34,7 @@
 .. moduleauthor:: Calin Pavel <calin.pavel@codemart.ro>
 .. moduleauthor:: Bogdan Neacsa <bogdan.neacsa@codemart.ro>
 """
+
 import json
 import os
 import shutil
@@ -43,13 +44,13 @@ from datetime import datetime
 from cherrypy._cpreqbody import Part
 from sqlalchemy.exc import IntegrityError
 from sqlalchemy.orm.attributes import manager_of_class
-
 from tvb.basic.logger.builder import get_logger
 from tvb.basic.neotraits.ex import TraitTypeError, TraitAttributeError
 from tvb.basic.profile import TvbProfile
 from tvb.config import VIEW_MODEL2ADAPTER, TVB_IMPORTER_MODULE, TVB_IMPORTER_CLASS
 from tvb.config.algorithm_categories import UploadAlgorithmCategoryConfig, DEFAULTDATASTATE_INTERMEDIATE
 from tvb.core.adapters.abcadapter import ABCAdapter
+from tvb.core.adapters.exceptions import IntrospectionException
 from tvb.core.entities import load
 from tvb.core.entities.file.files_update_manager import FilesUpdateManager
 from tvb.core.entities.file.simulator.burst_configuration_h5 import BurstConfigurationH5
@@ -206,7 +207,9 @@ class ImportService(object):
             # Import images and move them from temp into target
             self._store_imported_images(project, temp_project_path, project.name)
             if StorageInterface.encryption_enabled():
-                self.storage_interface.remove_project(project, True)
+                project_folder = self.storage_interface.get_project_folder(project.name)
+                self.storage_interface.sync_folders(project_folder)
+                self.storage_interface.remove_folder(project_folder)
 
     def _load_datatypes_from_operation_folder(self, src_op_path, operation_entity, datatype_group):
         """
@@ -247,7 +250,7 @@ class ImportService(object):
                     'Imported file depends on datatypes that do not exist. Please upload '
                     'those first!')
 
-    def _store_or_link_burst_config(self, burst_config, bc_path, project_id):
+    def _store_or_link_burst_config(self, burst_config, bc_path):
         bc_already_in_tvb = dao.get_generic_entity(BurstConfiguration, burst_config.gid, 'gid')
         if len(bc_already_in_tvb) == 0:
             self.store_datatype(burst_config, bc_path)
@@ -287,16 +290,19 @@ class ImportService(object):
                 if self.storage_interface.ends_with_tvb_file_extension(metadata_file):
                     self._import_image(root, metadata_file, project.id, target_images_path)
 
-    @staticmethod
-    def _populate_view_model2adapter():
+    def _populate_view_model2adapter(self):
         if len(VIEW_MODEL2ADAPTER) > 0:
             return VIEW_MODEL2ADAPTER
         view_model2adapter = {}
         algos = dao.get_all_algorithms()
         for algo in algos:
-            adapter = ABCAdapter.build_adapter(algo)
-            view_model_class = adapter.get_view_model_class()
-            view_model2adapter[view_model_class] = algo
+            try:
+                adapter = ABCAdapter.build_adapter(algo)
+                view_model_class = adapter.get_view_model_class()
+                view_model2adapter[view_model_class] = algo
+            except IntrospectionException:
+                self.logger.exception("Could not load %s" % algo)
+
         return view_model2adapter
 
     def _retrieve_operations_in_order(self, project, import_path, importer_operation_id=None):
@@ -465,7 +471,7 @@ class ImportService(object):
                     if isinstance(dt, BurstConfiguration):
                         if op_group:
                             dt.fk_operation_group = op_group.id
-                        all_stored_dts_count += self._store_or_link_burst_config(dt, dt_path, project.id)
+                        all_stored_dts_count += self._store_or_link_burst_config(dt, dt_path)
                     else:
                         dts[dt_path] = dt
                         if op_group:
