@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -44,7 +44,6 @@ from tvb.basic.profile import TvbProfile
 from tvb.config.init.initializer import command_initializer
 from tvb.config.init.introspector_registry import IntrospectionRegistry
 from tvb.core.adapters.abcadapter import ABCAdapter
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.file.simulator.view_model import SimulatorAdapterModel
 from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.model.model_operation import STATUS_FINISHED
@@ -55,6 +54,7 @@ from tvb.core.services.operation_service import OperationService
 from tvb.core.services.project_service import ProjectService
 from tvb.core.services.simulator_service import SimulatorService
 from tvb.core.services.user_service import UserService
+from tvb.storage.storage_interface import StorageInterface
 
 command_initializer()
 LOG = get_logger(__name__)
@@ -101,7 +101,7 @@ def import_conn_zip(project_id, zip_path):
     view_model = ZIPConnectivityImporterModel()
     view_model.uploaded = zip_path
 
-    return OperationService().fire_operation(importer, project.administrator, project_id, view_model=view_model)[0]
+    return OperationService().fire_operation(importer, project.administrator, project_id, view_model=view_model)
 
 
 def import_conn_h5(project_id, h5_path):
@@ -114,11 +114,11 @@ def import_conn_h5(project_id, h5_path):
     uq_name = "%s-Connectivity" % date_str
     new_path = os.path.join(TvbProfile.current.TVB_TEMP_FOLDER, uq_name)
 
-    FilesHelper.copy_file(h5_path, new_path)
+    StorageInterface.copy_file(h5_path, new_path)
     importer = ABCAdapter.build_adapter_from_class(TVBImporter)
     view_model = importer.get_view_model_class()()
     view_model.data_file = new_path
-    return OperationService().fire_operation(importer, project.administrator, project_id, view_model=view_model)[0]
+    return OperationService().fire_operation(importer, project.administrator, project_id, view_model=view_model)
 
 
 def fire_simulation(project_id, simulator_model):
@@ -150,7 +150,7 @@ def fire_operation(project_id, adapter_instance, view_model):
 
     # launch an operation and have the results stored both in DB and on disk
     launched_operation = OperationService().fire_operation(adapter_instance, project.administrator,
-                                                           project.id, view_model=view_model)[0]
+                                                           project.id, view_model=view_model)
     LOG.info("Operation launched....")
     return launched_operation
 
