@@ -37,11 +37,11 @@ import cherrypy
 import numpy
 
 import tvb.core.entities.model.model_burst as model_burst
-from tvb.adapters.simulator.equation_forms import get_form_for_equation, TemporalEquationsEnum
-from tvb.adapters.simulator.integrator_forms import get_form_for_integrator, NoiseTypesEnum
-from tvb.adapters.simulator.model_forms import get_form_for_model, ModelsEnum
-from tvb.adapters.simulator.noise_forms import get_form_for_noise
-from tvb.adapters.simulator.simulator_fragments import SimulatorModelFragment, SimulatorIntegratorFragment
+from tvb.adapters.forms.equation_forms import get_form_for_equation, TemporalEquationsEnum
+from tvb.adapters.forms.integrator_forms import get_form_for_integrator, NoiseTypesEnum
+from tvb.adapters.forms.model_forms import get_form_for_model, ModelsEnum
+from tvb.adapters.forms.noise_forms import get_form_for_noise
+from tvb.adapters.forms.simulator_fragments import SimulatorModelFragment, SimulatorIntegratorFragment
 from tvb.adapters.visualizers.phase_plane_interactive import phase_space_d3
 from tvb.basic.logger.builder import get_logger
 from tvb.basic.neotraits.api import TVBEnum
@@ -182,11 +182,9 @@ class DynamicModelController(BurstBaseController):
         }
 
     def _update_integrator(self, dynamic, integrator):
-        dynamic.integrator = integrator
-        dynamic.model.integrator = integrator
-        dynamic.model.configure()
         self._configure_integrator_noise(integrator, dynamic.model)
-        dynamic.phase_plane = phase_space_d3(dynamic.model, dynamic.integrator)
+        dynamic.integrator = integrator
+        dynamic.phase_plane.integrator = integrator
 
     def _change_integrator(self, dynamic, field_value):
         integrator = TVBEnum.string_to_enum(list(IntegratorViewModelsEnum), field_value).instance
@@ -310,16 +308,16 @@ class DynamicModelController(BurstBaseController):
         """
         ret = []
         model_form_class = get_form_for_model(type(model))
-        for name in model_form_class.get_params_configurable_in_phase_plane():
-            attr = getattr(type(model), name)
+        for param in model_form_class().get_params_configurable_in_phase_plane():
+            attr = getattr(type(model), param.name)
             ranger = attr.domain
             if ranger is None:
-                DynamicModelController.LOGGER.warning("Param %s doesn't have a domain specified" % (name))
+                DynamicModelController.LOGGER.warning("Param %s doesn't have a domain specified" % param.name)
                 continue
             default = float(attr.default)
 
             ret.append({
-                'name': name,
+                'name': param.name,
                 'label': attr.label,
                 'description': attr.doc,
                 'min': ranger.lo,
@@ -392,9 +390,9 @@ class DynamicModelController(BurstBaseController):
         model_parameters = []
 
         model_form_class = get_form_for_model(type(model))
-        for name in model_form_class.get_params_configurable_in_phase_plane():
-            value = getattr(model, name)[0]
-            model_parameters.append((name, value))
+        for param in model_form_class().get_params_configurable_in_phase_plane():
+            value = getattr(model, param.name)[0]
+            model_parameters.append((param.name, value))
 
         entity = model_burst.Dynamic(
             dynamic_name,
