@@ -41,7 +41,9 @@ import cherrypy
 import formencode
 import numpy
 import six
+from tvb.adapters.forms.equation_forms import get_form_for_equation
 
+from tvb.basic.neotraits.api import TVBEnum, SubformEnum
 from tvb.basic.neotraits.ex import TraitValueError
 from tvb.core.adapters import constants
 from tvb.core.adapters.abcadapter import ABCAdapter
@@ -63,10 +65,12 @@ from tvb.interfaces.web.controllers import common
 from tvb.interfaces.web.controllers.autologging import traced
 from tvb.interfaces.web.controllers.base_controller import BaseController
 from tvb.interfaces.web.controllers.common import InvalidFormValues
-from tvb.interfaces.web.controllers.decorators import expose_fragment, handle_error, check_user, expose_json
+from tvb.interfaces.web.controllers.decorators import expose_fragment, handle_error, check_user, expose_json, \
+    using_template
 from tvb.interfaces.web.controllers.decorators import expose_page, settings, context_selected, expose_numpy_array
 from tvb.interfaces.web.controllers.simulator.simulator_controller import SimulatorController
 from tvb.interfaces.web.entities.context_selected_adapter import SelectedAdapterContext
+from tvb.adapters.creators.local_connectivity_creator import LocalConnectivityCreatorModel, KEY_LCONN
 
 KEY_CONTENT = ABCDisplayer.KEY_CONTENT
 FILTER_FIELDS = "fields"
@@ -92,6 +96,7 @@ class FlowController(BaseController):
         self.context = SelectedAdapterContext()
         self.operation_services = OperationService()
         self.simulator_controller = SimulatorController()
+        self.enum_members = SubformEnum.get_enum_members()
 
         analyze_category, groups = self.algorithm_service.get_analyze_groups()
         adapters_list = []
@@ -100,7 +105,7 @@ class FlowController(BaseController):
             if len(adapter_group.children) > 1:
                 ids = [str(child.id) for child in adapter_group.children]
                 ids = ','.join(ids)
-                adapter_link = '/flow/show_group_of_algorithms/' + str(analyze_category.id) + "/" + ids
+                adapter_link = self.build_path('/flow/show_group_of_algorithms/' + str(analyze_category.id) + "/" + ids)
             else:
                 adapter_link = self.get_url_adapter(analyze_category.id, adapter_group.children[0].id)
 
@@ -129,7 +134,7 @@ class FlowController(BaseController):
             message = 'Could not load analyzers!'
             common.set_warning_message(message)
             self.logger.warning(message)
-            raise cherrypy.HTTPRedirect('/tvb')
+            self.redirect('/tvb')
 
     @expose_page
     @settings
@@ -141,6 +146,7 @@ class FlowController(BaseController):
         template_specification = dict(mainContent="header_menu", section_name='connectivity', controlPage=None,
                                       title="Select an algorithm", displayControl=False, subsection_name='step',
                                       submenu_list=self.connectivity_submenu)
+        common.add2session(KEY_LCONN, LocalConnectivityCreatorModel)
         return self.fill_default_attributes(template_specification)
 
     @staticmethod
@@ -157,7 +163,7 @@ class FlowController(BaseController):
             back_page_link = '/project/viewoperations/' + str(project.id)
         else:
             back_page_link = '/project/editstructure/' + str(project.id)
-        return back_page_link
+        return BaseController.build_path(back_page_link)
 
     @expose_page
     @settings
@@ -216,7 +222,7 @@ class FlowController(BaseController):
         back_page_link = self._compute_back_link(back_page, project)
 
         if algorithm is None:
-            raise cherrypy.HTTPRedirect("/tvb?error=True")
+            self.redirect("/tvb?error=True")
 
         if cherrypy.request.method == 'POST' and cancel:
             raise cherrypy.HTTPRedirect(back_page_link)
@@ -231,7 +237,7 @@ class FlowController(BaseController):
             template_specification = self.get_template_for_adapter(project.id, step_key, algorithm,
                                                                    submit_link, is_burst=is_burst)
         if template_specification is None:
-            raise cherrypy.HTTPRedirect('/tvb')
+            self.redirect('/tvb')
 
         if KEY_CONTROLLS not in template_specification:
             template_specification[KEY_CONTROLLS] = None
@@ -281,9 +287,9 @@ class FlowController(BaseController):
         """ Execute HTTP POST on a generic step."""
         errors = None
         adapter_instance = ABCAdapter.build_adapter(algorithm)
-
+        user = common.get_logged_user()
         try:
-            form = self.algorithm_service.fill_adapter_form(adapter_instance, data, project_id)
+            form = self.algorithm_service.fill_adapter_form(adapter_instance, data, project_id, user)
             if form.validate():
                 try:
                     view_model = form.get_view_model()()
@@ -299,9 +305,13 @@ class FlowController(BaseController):
 
             adapter_instance.submit_form(form)
 
+            if not self.operation_services.fits_max_operation_size(adapter_instance, view_model, project_id):
+                common.set_error_message(self.MAX_SIZE_ERROR_MSG)
+                return {}
+
             if issubclass(type(adapter_instance), ABCDisplayer):
                 adapter_instance.current_project_id = project_id
-                adapter_instance.user_id = common.get_logged_user().id
+                adapter_instance.user_id = user.id
                 result = adapter_instance.launch(view_model)
                 if isinstance(result, dict):
                     return result
@@ -309,8 +319,7 @@ class FlowController(BaseController):
                     common.set_error_message("Invalid result returned from Displayer! Dictionary is expected!")
                 return {}
 
-            self.operation_services.fire_operation(adapter_instance, common.get_logged_user(), project_id,
-                                                   view_model=view_model)
+            self.operation_services.fire_operation(adapter_instance, user, project_id, view_model=view_model)
             common.set_important_message("Launched an operation.")
 
         except formencode.Invalid as excep:
@@ -341,9 +350,9 @@ class FlowController(BaseController):
                 title = title + " - " + group.displayname
 
             adapter_instance = self.algorithm_service.prepare_adapter(stored_adapter)
-
+            user = common.get_logged_user()
             adapter_form = self.algorithm_service.prepare_adapter_form(adapter_instance=adapter_instance,
-                                                                       project_id=project_id)
+                                                                       project_id=project_id, user=user)
             vm = self.context.get_view_model_from_session()
             if vm and type(vm) == adapter_form.get_view_model():
                 adapter_form.fill_from_trait(vm)
@@ -490,7 +499,7 @@ class FlowController(BaseController):
 
         algorithm = self.algorithm_service.get_algorithm_by_identifier(algorithm_id)
         if is_upload:
-            submit_link = "/project/launchloader/" + str(project_id) + "/" + str(algorithm_id)
+            submit_link = BaseController.build_path("/project/launchloader/" + str(project_id) + "/" + str(algorithm_id))
         else:
             submit_link = self.get_url_adapter(algorithm.fk_category, algorithm.id, back_page)
 
@@ -514,7 +523,7 @@ class FlowController(BaseController):
         # Display the inputs tree for the current op
         category_id = operation.algorithm.fk_category
         algo_id = operation.fk_from_algo
-        raise cherrypy.HTTPRedirect("/flow/" + str(category_id) + "/" + str(algo_id))
+        self.redirect("/flow/" + str(category_id) + "/" + str(algo_id))
 
     @cherrypy.expose
     @handle_error(redirect=True)
@@ -533,7 +542,7 @@ class FlowController(BaseController):
             operation = OperationService.load_operation(int(first_op.id))
         self.simulator_controller.copy_simulator_configuration(operation.burst.id)
 
-        raise cherrypy.HTTPRedirect("/burst/")
+        self.redirect("/burst/")
 
     @expose_json
     def cancel_or_remove_operation(self, operation_id, is_group, remove_after_stop=False):
@@ -669,3 +678,18 @@ class FlowController(BaseController):
                                                   **parameters)
 
         return [True, 'Stored the exploration material successfully']
+
+    @cherrypy.expose
+    @using_template('form_fields/form_field')
+    @handle_error(redirect=False)
+    @check_user
+    def refresh_subform(self, data_name, subform_label, spatial_model_key):
+        data_class = TVBEnum.string_to_enum(self.enum_members, data_name).value
+
+        spatial_model = common.get_from_session(spatial_model_key)
+        equation_info = spatial_model.get_equation_information()
+        setattr(spatial_model, equation_info[subform_label], data_class())
+
+        adapter_form = get_form_for_equation(data_class)()
+
+        return {'adapter_form': adapter_form}
