@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -35,30 +35,34 @@ This represents the Controller part (from MVC).
 .. moduleauthor:: Lia Domide <lia.domide@codemart.ro>
 .. moduleauthor:: Bogdan Neacsa <bogdan.neacsa@codemart.ro>
 """
-
 import cherrypy
 import formencode
+from cherrypy.lib.static import serve_file
 from formencode import validators
 from simplejson import JSONEncoder
-from cherrypy.lib.static import serve_file
-from tvb.adapters.exporters.export_manager import ExportManager
-from tvb.config.init.introspector_registry import IntrospectionRegistry
 import tvb.core.entities.model.model_operation as model
-from tvb.core.entities.load import load_entity_by_gid
+from tvb.adapters.creators.tumor_dataset_creator import TumorDatasetCreator
+from tvb.adapters.exporters.export_manager import ExportManager
+from tvb.basic.profile import TvbProfile
+from tvb.config.init.introspector_registry import IntrospectionRegistry
 from tvb.core.entities.filters.factory import StaticFiltersFactory
-from tvb.core.services.operation_service import OperationService
-from tvb.core.services.project_service import ProjectService
-from tvb.core.services.import_service import ImportService
-from tvb.core.services.exceptions import ServicesBaseException, ProjectServiceException
+from tvb.core.entities.load import load_entity_by_gid
+from tvb.core.entities.storage import dao
 from tvb.core.services.exceptions import RemoveDataTypeException
-from tvb.core.utils import string2bool
-from tvb.interfaces.web.controllers.autologging import traced
-from tvb.interfaces.web.entities.context_overlay import OverlayTabDefinition
+from tvb.core.services.exceptions import ServicesBaseException, ProjectServiceException
+from tvb.core.services.import_service import ImportService
+from tvb.core.services.operation_service import OperationService
 from tvb.interfaces.web.controllers import common
-from tvb.interfaces.web.controllers.decorators import settings, check_user, handle_error
-from tvb.interfaces.web.controllers.decorators import expose_page, expose_json, expose_fragment
+from tvb.interfaces.web.controllers.autologging import traced
 from tvb.interfaces.web.controllers.base_controller import BaseController
+from tvb.interfaces.web.controllers.decorators import expose_page, expose_json, expose_fragment
+from tvb.interfaces.web.controllers.decorators import settings, check_user, handle_error
 from tvb.interfaces.web.controllers.flow_controller import FlowController
+from tvb.interfaces.web.entities.context_overlay import OverlayTabDefinition
+from tvb.interfaces.web.entities.context_simulator import SimulatorContext
+from tvb.interfaces.web.structure import WebStructure
+from tvb.storage.h5.utils import string2bool
+from tvb.storage.storage_interface import StorageInterface
 
 
 @traced('generate_call_out_control', exclude=True)
@@ -75,7 +79,6 @@ class ProjectController(BaseController):
 
     def __init__(self):
         super(ProjectController, self).__init__()
-        self.project_service = ProjectService()
         self.flow_controller = FlowController()
 
     @expose_page
@@ -86,11 +89,10 @@ class ProjectController(BaseController):
         """
         current_project = common.get_current_project()
         if current_project is None:
-            raise cherrypy.HTTPRedirect("/project/viewall")
+            self.redirect("/project/viewall")
         template_specification = dict(mainContent="project/project_submenu", title="TVB Project Menu")
         return self.fill_default_attributes(template_specification)
 
-
     @expose_page
     @settings
     def viewall(self, create=False, page=1, selected_project_id=None, **_):
@@ -99,7 +101,7 @@ class ProjectController(BaseController):
         """
         page = int(page)
         if cherrypy.request.method == 'POST' and create:
-            raise cherrypy.HTTPRedirect('/project/editone')
+            self.redirect('/project/editone')
         current_user_id = common.get_logged_user().id
 
         ## Select project if user choose one.
@@ -112,13 +114,12 @@ class ProjectController(BaseController):
                 self.logger.warning("Could not select project: " + str(selected_project_id))
                 common.set_error_message("Could not select project: " + str(selected_project_id))
 
-        #Prepare template response
+        # Prepare template response
         prjs, pages_no = self.project_service.retrieve_projects_for_user(current_user_id, page)
         template_specification = dict(mainContent="project/viewall", title="Available TVB Projects",
                                       projectsList=prjs, page_number=page, total_pages=pages_no)
         return self.fill_default_attributes(template_specification, 'list')
 
-
     @cherrypy.expose
     @handle_error(redirect=True)
     @check_user
@@ -134,8 +135,7 @@ class ProjectController(BaseController):
         except ServicesBaseException as excep:
             self.logger.warning(excep.message)
             common.set_error_message(excep.message)
-        raise cherrypy.HTTPRedirect('/project/viewall')
-
+        self.redirect('/project/viewall')
 
     def _remove_project(self, project_id):
         """Private method for removing project."""
@@ -147,7 +147,7 @@ class ProjectController(BaseController):
             common.set_error_message(exc.message)
         prj = common.get_current_project()
         if prj is not None and prj.id == int(project_id):
-            common.clean_project_data_from_session()
+            SimulatorContext().clean_project_data_from_session()
 
     @expose_page
     @settings
@@ -157,10 +157,10 @@ class ProjectController(BaseController):
         new entity, otherwise we are to edit and existent one.
         """
         if cherrypy.request.method == 'POST' and cancel:
-            raise cherrypy.HTTPRedirect('/project')
+            self.redirect('/project')
         if cherrypy.request.method == 'POST' and delete:
             self._remove_project(project_id)
-            raise cherrypy.HTTPRedirect('/project/viewall')
+            self.redirect('/project/viewall')
 
         current_user = common.get_logged_user()
         is_create = False
@@ -173,7 +173,8 @@ class ProjectController(BaseController):
             if not save:
                 # Only when we do not have submitted data,
                 # populate fields with initial values for edit.
-                data = dict(name=current_project.name, description=current_project.description)
+                data = dict(name=current_project.name, description=current_project.description,
+                            disable_imports=current_project.disable_imports, max_operation_size=current_project.max_operation_size)
             data["administrator"] = current_project.administrator.display_name
             admin_username = current_project.administrator.username
             self._mark_selected(current_project)
@@ -186,15 +187,19 @@ class ProjectController(BaseController):
             if cherrypy.request.method == 'POST' and save:
                 data = EditForm().to_python(data)
                 saved_project = self.project_service.store_project(current_user, is_create, project_id, **data)
+                if StorageInterface.encryption_enabled() and is_create:
+                    project_folder = self.storage_interface.get_project_folder(saved_project.name)
+                    self.storage_interface.sync_folders(project_folder)
+                    self.storage_interface.remove_folder(project_folder)
                 self._mark_selected(saved_project)
-                raise cherrypy.HTTPRedirect('/project/viewall')
+                self.redirect('/project/viewall')
         except formencode.Invalid as excep:
             self.logger.debug(str(excep))
             template_specification[common.KEY_ERRORS] = excep.unpack_errors()
         except ProjectServiceException as excep:
             self.logger.debug(str(excep))
             common.set_error_message(excep.message)
-            raise cherrypy.HTTPRedirect('/project/viewall')
+            self.redirect('/project/viewall')
 
         all_users, members, pages = self.user_service.get_users_for_project(current_user.username, project_id)
         template_specification['usersList'] = all_users
@@ -203,7 +208,6 @@ class ProjectController(BaseController):
         template_specification['usersCurrentPage'] = 1
         return self.fill_default_attributes(template_specification, 'properties')
 
-
     @expose_fragment('project/project_members')
     def getmemberspage(self, page, project_id=None):
         """Retrieve a new page of Project members."""
@@ -216,7 +220,6 @@ class ProjectController(BaseController):
         return dict(usersList=all_users, usersMembers=[m.id for m in members],
                     usersCurrentPage=page, editUsersEnabled=edit_enabled)
 
-
     @expose_json
     def set_visibility(self, entity_type, entity_gid, to_de_relevant):
         """
@@ -236,7 +239,6 @@ class ProjectController(BaseController):
         else:
             self.project_service.set_datatype_visibility(entity_gid, to_de_relevant)
 
-
     @expose_page
     @settings
     def viewoperations(self, project_id=None, page=1, filtername=None, reset_filters=None):
@@ -244,7 +246,7 @@ class ProjectController(BaseController):
         Display table of operations for a given project selected
         """
         if (project_id is None) or (not int(project_id)):
-            raise cherrypy.HTTPRedirect('/project')
+            self.redirect('/project')
 
         ## Toggle filters
         filters = self.__get_operations_filters()
@@ -277,15 +279,15 @@ class ProjectController(BaseController):
                                       filters=filters, no_filter_selected=(selected_filters is None), model=model)
         return self.fill_default_attributes(template_specification, 'operations')
 
-
     @expose_fragment("call_out_project")
     def generate_call_out_control(self):
         """
         Returns the content of a confirmation dialog, with a given question. 
         """
         self.update_operations_count()
-        return {'selectedProject': common.get_current_project()}
-
+        template = {'selectedProject': common.get_current_project()}
+        template = self.fill_default_attributes(template)
+        return template
 
     def __get_operations_filters(self):
         """
@@ -303,7 +305,6 @@ class ProjectController(BaseController):
             common.add2session(self.KEY_OPERATION_FILTERS, new_filters)
             return new_filters
 
-
     @expose_fragment("overlay_confirmation")
     def show_confirmation_overlay(self, **data):
         """
@@ -355,7 +356,8 @@ class ProjectController(BaseController):
                                   "isGroup": is_group,
                                   "isRelevant": is_relevant,
                                   "nodeType": 'datatype',
-                                  "backPageIdentifier": back_page}
+                                  "backPageIdentifier": back_page,
+                                  "canEncrypt": TvbProfile.current.web.ENCRYPT_STORAGE}
         template_specification.update(linkable_projects_dict)
 
         overlay_class = "can-browse editor-node node-type-" + str(current_type).lower()
@@ -403,7 +405,6 @@ class ProjectController(BaseController):
             template_specification[common.KEY_MESSAGE_TYPE] = "warningMessage"
         return template_specification
 
-
     @expose_fragment('project/linkable_projects')
     def get_linkable_projects(self, datatype_id, is_group, entity_gid):
         """
@@ -414,7 +415,6 @@ class ProjectController(BaseController):
         template_specification["isGroup"] = is_group
         return template_specification
 
-
     def _get_linkable_projects_dict(self, datatype_id):
         """" UI ready dictionary with projects in which current DataType can be linked."""
         self.logger.debug("Searching projects to link for DT " + str(datatype_id))
@@ -464,7 +464,6 @@ class ProjectController(BaseController):
                                                               "project/details_operation_overlay", overlay_class)
         return self.flow_controller.fill_default_attributes(template_specification)
 
-
     def _compute_operation_details(self, entity_gid, is_group=False):
         """
         Returns a dictionary which contains the details for the given operation.
@@ -494,12 +493,10 @@ class ProjectController(BaseController):
                                   "isRelevant": operation.visible}
         return template_specification
 
-
     def get_project_structure_grouping(self):
         user = common.get_logged_user()
         return user.get_project_structure_grouping()
 
-
     def set_project_structure_grouping(self, first, second):
         user = common.get_logged_user()
         user.set_project_structure_grouping(first, second)
@@ -515,7 +512,7 @@ class ProjectController(BaseController):
         try:
             int(project_id)
         except (ValueError, TypeError):
-            raise cherrypy.HTTPRedirect('/project')
+            self.redirect('/project')
 
         if first_level is None or second_level is None:
             first_level, second_level = self.get_project_structure_grouping()
@@ -524,14 +521,17 @@ class ProjectController(BaseController):
         self._mark_selected(selected_project)
         data = self.project_service.get_filterable_meta()
         filters = StaticFiltersFactory.build_datatype_filters(selected=visibility_filter)
+        tumor_creator_algorithm = dao.get_algorithm_by_module(TumorDatasetCreator.__module__,
+                                                              TumorDatasetCreator.__name__)
+
         template_specification = dict(mainContent="project/structure",
                                       title=selected_project.name,
                                       project=selected_project, data=data,
                                       firstLevelSelection=first_level, secondLevelSelection=second_level,
-                                      filterInputValue=filter_input, filters=filters)
+                                      filterInputValue=filter_input, filters=filters,
+                                      tumorCreatorAlgorithmId=tumor_creator_algorithm.id)
         return self.fill_default_attributes(template_specification, 'data')
 
-
     @expose_fragment("overlay")
     def get_data_uploader_overlay(self, project_id):
         """
@@ -554,10 +554,10 @@ class ProjectController(BaseController):
         template_specification['uploadAlgorithms'] = upload_algorithms
         template_specification['projectId'] = project_id
         template_specification['algorithmsInterface'] = algorithms_interface
+        template_specification['disable_imports'] = dao.get_project_by_id(project_id).disable_imports
 
         return self.flow_controller.fill_default_attributes(template_specification)
 
-
     @expose_fragment("overlay")
     def get_project_uploader_overlay(self):
         """
@@ -569,13 +569,12 @@ class ProjectController(BaseController):
 
         return self.flow_controller.fill_default_attributes(template_specification)
 
-
     @expose_page
     def launchloader(self, project_id, algorithm_id, cancel=False, **data):
         """ 
         Start Upload mechanism
         """
-        success_link = "/project/editstructure/" + str(project_id)
+        success_link = self.build_path("/project/editstructure/" + str(project_id))
         # do not allow GET
         if cherrypy.request.method != 'POST' or cancel:
             raise cherrypy.HTTPRedirect(success_link)
@@ -618,23 +617,14 @@ class ProjectController(BaseController):
         encoder = JSONEncoder()
         return encoder.iterencode(json_structure)
 
-
     @cherrypy.expose
     @handle_error(redirect=False)
     @check_user
-    def createlink(self, link_data, project_id, is_group):
+    def createlink(self, link_data, project_id):
         """
-        Delegate the creation of the actual link to the flow service.
+        Delegate the creation of the actual link to the algorithm service.
         """
-        if not string2bool(str(is_group)):
-            self.algorithm_service.create_link([link_data], project_id)
-        else:
-            all_data = self.project_service.get_datatype_in_group(link_data)
-            # Link all Dts in group and the DT_Group entity
-            data_ids = [data.id for data in all_data]
-            data_ids.append(int(link_data))
-            self.algorithm_service.create_link(data_ids, project_id)
-
+        self.algorithm_service.create_link(link_data, project_id)
 
     @cherrypy.expose
     @handle_error(redirect=False)
@@ -651,7 +641,6 @@ class ProjectController(BaseController):
                 self.algorithm_service.remove_link(data.id, project_id)
             self.algorithm_service.remove_link(int(link_data), project_id)
 
-
     @cherrypy.expose
     @handle_error(redirect=False)
     @check_user
@@ -672,7 +661,6 @@ class ProjectController(BaseController):
             return excep.message
         return None
 
-
     @cherrypy.expose
     @handle_error(redirect=False)
     @check_user
@@ -688,18 +676,18 @@ class ProjectController(BaseController):
             common.set_error_message(excep.message)
             return excep.message
 
-
     @cherrypy.expose
     @handle_error(redirect=False)
     @check_user
-    def downloaddatatype(self, data_gid, export_module):
+    def downloaddatatype(self, data_gid, export_module, **data):
         """ Export the data to a default path of TVB_STORAGE/PROJECTS/project_name """
         current_prj = common.get_current_project()
         # Load data by GID
         entity = load_entity_by_gid(data_gid)
         # Do real export
         export_mng = ExportManager()
-        file_name, file_path, delete_file = export_mng.export_data(entity, export_module, current_prj)
+        file_name, file_path, delete_file = export_mng.export_data(entity, export_module, current_prj,
+                                                                   data.get('exporter_key'))
         if delete_file:
             # We force parent folder deletion because export process generated it.
             self.mark_file_for_delete(file_path, True)
@@ -707,7 +695,6 @@ class ProjectController(BaseController):
         self.logger.debug("Data exported in file: " + str(file_path))
         return serve_file(file_path, "application/x-download", "attachment", file_name)
 
-
     @cherrypy.expose
     @handle_error(redirect=False)
     @check_user
@@ -729,7 +716,7 @@ class ProjectController(BaseController):
         """
         Overwrite base controller to add required parameters for adapter templates.
         """
-        template_dictionary[common.KEY_SECTION] = 'project'
+        template_dictionary[common.KEY_SECTION] = WebStructure.SECTION_PROJECT
         template_dictionary[common.KEY_SUB_SECTION] = subsection
         template_dictionary[common.KEY_INCLUDE_RESOURCES] = 'project/included_resources'
         BaseController.fill_default_attributes(self, template_dictionary)
@@ -748,6 +735,5 @@ class EditForm(formencode.Schema):
     administrator = validators.UnicodeString(not_empty=False)
     project_id = validators.UnicodeString(not_empty=False)
     visited_pages = validators.UnicodeString(not_empty=False)
-
-
-
+    max_operation_size = validators.Int(not_empty=False, min=0)
+    disable_imports = validators.Bool()
