@@ -34,14 +34,14 @@ from cherrypy.lib.static import serve_file
 from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
 from tvb.adapters.datatypes.db.simulation_history import SimulationHistoryIndex
 from tvb.adapters.exporters.export_manager import ExportManager
-from tvb.adapters.simulator.coupling_forms import get_form_for_coupling
-from tvb.adapters.simulator.equation_forms import get_form_for_equation
-from tvb.adapters.simulator.model_forms import get_form_for_model
-from tvb.adapters.simulator.monitor_forms import get_form_for_monitor
-from tvb.adapters.simulator.noise_forms import get_form_for_noise
-from tvb.adapters.simulator.range_parameters import SimulatorRangeParameters
-from tvb.adapters.simulator.simulator_adapter import SimulatorAdapterForm
-from tvb.adapters.simulator.simulator_fragments import *
+from tvb.adapters.forms.coupling_forms import get_form_for_coupling
+from tvb.adapters.forms.equation_forms import get_form_for_equation
+from tvb.adapters.forms.model_forms import get_form_for_model
+from tvb.adapters.forms.monitor_forms import get_form_for_monitor
+from tvb.adapters.forms.noise_forms import get_form_for_noise
+from tvb.adapters.simulator.range_parameters import RangeParametersCollector
+from tvb.adapters.simulator.simulator_adapter import SimulatorAdapterForm, SimulatorAdapter
+from tvb.adapters.forms.simulator_fragments import *
 from tvb.config.init.introspector_registry import IntrospectionRegistry
 from tvb.core.entities.file.simulator.view_model import AdditiveNoiseViewModel, BoldViewModel
 from tvb.core.entities.file.simulator.view_model import IntegratorStochasticViewModel
@@ -72,7 +72,7 @@ class SimulatorController(BurstBaseController):
 
     def __init__(self):
         BurstBaseController.__init__(self)
-        self.range_parameters = SimulatorRangeParameters()
+        self.range_parameters = RangeParametersCollector()
         self.burst_service = BurstService()
         self.simulator_service = SimulatorService()
         self.cached_simulator_algorithm = self.algorithm_service.get_algorithm_by_module_and_class(
@@ -183,7 +183,7 @@ class SimulatorController(BurstBaseController):
 
         next_form = self.algorithm_service.prepare_adapter_form(
             form_instance=get_form_for_coupling(type(session_stored_simulator.coupling))())
-        self.range_parameters.coupling_parameters = next_form.get_range_parameters()
+        self.range_parameters.range_param_forms[FormWithRanges.COUPLING_FRAGMENT_KEY] = next_form
         next_form.fill_from_trait(session_stored_simulator.coupling)
 
         rendering_rules = SimulatorFragmentRenderingRules(
@@ -223,7 +223,7 @@ class SimulatorController(BurstBaseController):
             form = SimulatorSurfaceFragment()
             form.fill_from_post(data)
             self.simulator_service.reset_at_surface_change(is_simulation_copy, form, session_stored_simulator)
-            self.range_parameters.surface_parameters = None
+            self.range_parameters.range_param_forms.pop(FormWithRanges.CORTEX_FRAGMENT_KEY, None)
             form.fill_trait(session_stored_simulator)
 
             if session_stored_simulator.surface:
@@ -245,7 +245,7 @@ class SimulatorController(BurstBaseController):
             rm_fragment.fill_from_post(data)
             rm_fragment.fill_trait(session_stored_simulator.surface)
 
-        self.range_parameters.surface_parameters = rm_fragment.get_range_parameters()
+        self.range_parameters.range_param_forms[FormWithRanges.CORTEX_FRAGMENT_KEY] = rm_fragment
         rendering_rules = SimulatorFragmentRenderingRules(
             None, None, SimulatorWizzardURLs.SET_CORTEX_URL, is_simulation_copy, is_simulation_load,
             self.context.last_loaded_fragment_url, cherrypy.request.method)
@@ -290,7 +290,7 @@ class SimulatorController(BurstBaseController):
 
         form = self.algorithm_service.prepare_adapter_form(
             form_instance=get_form_for_model(type(session_stored_simulator.model))(is_branch))
-        self.range_parameters.model_parameters = form.get_range_parameters()
+        self.range_parameters.range_param_forms[FormWithRanges.MODEL_FRAGMENT_KEY] = form
         form.fill_from_trait(session_stored_simulator.model)
 
         rendering_rules = SimulatorFragmentRenderingRules(
@@ -363,7 +363,7 @@ class SimulatorController(BurstBaseController):
             else:
                 self.context.add_last_loaded_form_url_to_session(SimulatorWizzardURLs.SET_MONITORS_URL)
 
-            self.range_parameters.integrator_noise_parameters = None
+            self.range_parameters.range_param_forms.pop(FormWithRanges.NOISE_FRAGMENT_KEY, None)
 
         rendering_rules = SimulatorFragmentRenderingRules(
             None, None, SimulatorWizzardURLs.SET_INTEGRATOR_PARAMS_URL, is_simulation_copy,
@@ -378,7 +378,7 @@ class SimulatorController(BurstBaseController):
         if hasattr(integrator_noise_fragment, 'equation'):
             integrator_noise_fragment.equation.display_subform = False
 
-        self.range_parameters.integrator_noise_parameters = integrator_noise_fragment.get_range_parameters()
+        self.range_parameters.range_param_forms[FormWithRanges.NOISE_FRAGMENT_KEY] = integrator_noise_fragment
         integrator_noise_fragment.fill_from_trait(session_stored_simulator.integrator.noise)
 
         rendering_rules.form = integrator_noise_fragment
@@ -509,7 +509,7 @@ class SimulatorController(BurstBaseController):
             previous_form_action_url=previous_form_action_url)
 
         form_action_url, if_bold_url = self.get_urls_for_next_monitor_fragment(next_monitor, current_monitor)
-        self.monitors_handler.update_monitor(current_monitor, session_stored_simulator.is_surface_simulation)
+        self.monitors_handler.update_monitor(current_monitor, session_stored_simulator)
         return self.monitors_handler.handle_next_fragment_for_monitors(self.context, rendering_rules, current_monitor,
                                                                        next_monitor, False, form_action_url,
                                                                        if_bold_url)
@@ -607,8 +607,15 @@ class SimulatorController(BurstBaseController):
         burst_config = self.context.burst_config
         burst_config.start_time = datetime.now()
         burst_config.range1 = range_param1.to_json()
+        len_range = len(range_param1.get_range_values())
         if range_param2:
             burst_config.range2 = range_param2.to_json()
+            len_range *= len(range_param2.get_range_values())
+
+        if not self.simulator_service.operation_service.fits_max_operation_size(SimulatorAdapter(), session_stored_simulator,
+                                                                                self.context.project.id, len_range):
+            return {'error': self.MAX_SIZE_ERROR_MSG}
+
         burst_config = self.burst_service.prepare_burst_for_pse(burst_config)
         session_stored_simulator.operation_group_gid = uuid.UUID(burst_config.operation_group.gid)
         session_stored_simulator.ranges = json.dumps(burst_config.ranges)
@@ -653,6 +660,10 @@ class SimulatorController(BurstBaseController):
                                                                                        SimulationHistoryIndex)
             session_stored_simulator.history_gid = simulation_state_index[0].gid
 
+        if not self.simulator_service.operation_service.fits_max_operation_size(SimulatorAdapter(), session_stored_simulator,
+                                                                                self.context.project.id):
+            return {'error': self.MAX_SIZE_ERROR_MSG}
+
         burst_config.start_time = datetime.now()
         session_burst_config = self.burst_service.store_burst(burst_config)
 
@@ -695,13 +706,12 @@ class SimulatorController(BurstBaseController):
         try:
             burst_config = self.burst_service.load_burst_configuration(burst_config_id)
             storage_path = StorageInterface().get_project_folder(self.context.project.name,
-                                                                str(burst_config.fk_simulation))
+                                                                 str(burst_config.fk_simulation))
             simulator = h5.load_view_model(burst_config.simulator_gid, storage_path)
             last_loaded_form_url = self.get_url_for_final_fragment(burst_config)
             self.context.init_session_at_burst_loading(burst_config, simulator, last_loaded_form_url)
 
             form = self.prepare_first_fragment()
-            self.monitors_handler.build_list_of_monitors_from_view_models(self.context.simulator)
             rendering_rules = SimulatorFragmentRenderingRules(form, SimulatorWizzardURLs.SET_CONNECTIVITY_URL,
                                                               is_simulation_readonly_load=True, is_first_fragment=True)
             return rendering_rules.to_dict()
@@ -715,7 +725,6 @@ class SimulatorController(BurstBaseController):
     def _prepare_first_fragment_for_burst_copy(self, burst_config_id, burst_name_format):
         simulator, burst_config_copy = self.burst_service.prepare_data_for_burst_copy(
             burst_config_id, burst_name_format, self.context.project)
-        self.monitors_handler.build_list_of_monitors_from_view_models(simulator)
 
         last_loaded_form_url = self.get_url_for_final_fragment(burst_config_copy)
         self.context.init_session_at_copy_preparation(burst_config_copy, simulator, last_loaded_form_url)
@@ -744,7 +753,6 @@ class SimulatorController(BurstBaseController):
     def reset_simulator_configuration(self):
         burst_config = BurstConfiguration(self.context.project.id)
         self.context.init_session_at_sim_reset(burst_config, SimulatorWizzardURLs.SET_CONNECTIVITY_URL)
-        self.monitors_handler.clear_next_monitors_dict()
 
         form = self.prepare_first_fragment()
         rendering_rules = SimulatorFragmentRenderingRules(form, SimulatorWizzardURLs.SET_CONNECTIVITY_URL,
@@ -807,7 +815,6 @@ class SimulatorController(BurstBaseController):
                 dts_folder = os.path.join(sim_folder, StorageInterface.EXPORTED_SIMULATION_DTS_DIR)
                 ImportService().import_list_of_operations(self.context.project, dts_folder, False, None)
 
-                self.monitors_handler.build_list_of_monitors_from_view_models(simulator)
                 if burst_config.is_pse_burst():
                     last_loaded_form_url = SimulatorWizzardURLs.LAUNCH_PSE_URL
                 self.context.init_session_at_sim_config_from_zip(burst_config, simulator, last_loaded_form_url)
@@ -818,4 +825,4 @@ class SimulatorController(BurstBaseController):
             self.logger.warning(excep.message)
             self.context.set_warning_message(excep.message)
 
-        raise cherrypy.HTTPRedirect('/burst/')
+        self.redirect('/burst/')
