@@ -34,7 +34,7 @@
 """
 
 import json
-
+from tvb.adapters.forms.model_forms import get_model_to_form_dict
 from tvb.adapters.visualizers.surface_view import SurfaceURLGenerator
 from tvb.basic.logger.builder import get_logger
 from tvb.core.neocom import h5
@@ -44,6 +44,7 @@ from tvb.interfaces.web.controllers.autologging import traced
 from tvb.interfaces.web.controllers.base_controller import BaseController
 from tvb.interfaces.web.controllers.common import MissingDataException
 from tvb.interfaces.web.controllers.decorators import settings, expose_page, using_template
+from tvb.interfaces.web.structure import WebStructure
 
 PARAM_SURFACE = "surface"
 
@@ -59,9 +60,9 @@ class SpatioTemporalController(BaseController):
         BaseController.__init__(self)
         self.operation_service = OperationService()
         self.logger = get_logger(__name__)
-        editable_entities = [dict(link='/spatial/stimulus/region/step_1_submit/1/1', title='Region Stimulus',
+        editable_entities = [dict(link=self.build_path('/spatial/stimulus/region/step_1_submit/1/1'), title='Region Stimulus',
                                   subsection='regionstim', description='Create a new Stimulus on Region level'),
-                             dict(link='/spatial/stimulus/surface/step_1_submit/1/1', title='Surface Stimulus',
+                             dict(link=self.build_path('/spatial/stimulus/surface/step_1_submit/1/1'), title='Surface Stimulus',
                                   subsection='surfacestim', description='Create a new Stimulus on Surface level')]
         self.submenu_list = editable_entities
 
@@ -121,7 +122,7 @@ class SpatioTemporalController(BaseController):
         """
         Overwrite base controller to add required parameters for adapter templates.
         """
-        template_dictionary[common.KEY_SECTION] = 'stimulus'
+        template_dictionary[common.KEY_SECTION] = WebStructure.SECTION_STIMULUS
         template_dictionary[common.KEY_SUB_SECTION] = subsection
         template_dictionary[common.KEY_SUBMENU_LIST] = self.submenu_list
         template_dictionary[common.KEY_INCLUDE_RESOURCES] = 'spatial/included_resources'
@@ -154,3 +155,11 @@ class SpatioTemporalController(BaseController):
         rendering_dict.update({'showOnlineHelp': show_online_help})
         rendering_dict.update({'isCallout': False})
         return rendering_dict
+
+    def _prepare_model_params_list(self, model):
+        model_form = get_model_to_form_dict().get(type(model))
+        model_params = model_form().get_params_configurable_in_phase_plane()
+        if len(model_params) == 0:
+            self.logger.warning("The list with configurable parameters for the current model is empty!")
+
+        return model_params
