@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -37,13 +37,10 @@
 import json
 import uuid
 import cherrypy
-
 from tvb.adapters.creators.local_connectivity_creator import *
 from tvb.adapters.datatypes.h5.local_connectivity_h5 import LocalConnectivityH5
 from tvb.adapters.datatypes.h5.surface_h5 import SurfaceH5
-from tvb.adapters.simulator.equation_forms import get_form_for_equation
-from tvb.adapters.simulator.subform_helper import SubformHelper
-from tvb.adapters.simulator.subforms_mapping import get_ui_name_to_equation_dict
+from tvb.adapters.forms.equation_forms import get_form_for_equation
 from tvb.core.adapters.abcadapter import ABCAdapter
 from tvb.core.entities.load import try_get_last_datatype, load_entity_by_gid
 from tvb.core.neocom import h5
@@ -51,14 +48,15 @@ from tvb.interfaces.web.controllers import common
 from tvb.interfaces.web.controllers.autologging import traced
 from tvb.interfaces.web.controllers.base_controller import BaseController
 from tvb.interfaces.web.controllers.common import MissingDataException
-from tvb.interfaces.web.controllers.decorators import check_user, handle_error, using_template
+from tvb.interfaces.web.controllers.decorators import check_user, handle_error
 from tvb.interfaces.web.controllers.decorators import expose_fragment, expose_page, expose_json
 from tvb.interfaces.web.controllers.spatial.base_spatio_temporal_controller import SpatioTemporalController
+from tvb.interfaces.web.structure import WebStructure
 
 NO_OF_CUTOFF_POINTS = 20
 
-LOAD_EXISTING_URL = '/spatial/localconnectivity/load_local_connectivity'
-RELOAD_DEFAULT_PAGE_URL = '/spatial/localconnectivity/reset_local_connectivity'
+LOAD_EXISTING_URL = SpatioTemporalController.build_path('/spatial/localconnectivity/load_local_connectivity')
+RELOAD_DEFAULT_PAGE_URL = SpatioTemporalController.build_path('/spatial/localconnectivity/reset_local_connectivity')
 
 # Between steps/pages we keep a LocalConnectivityCreatorModel in session at this key
 KEY_LCONN = "local-conn"
@@ -120,8 +118,8 @@ class LocalConnectivityController(SpatioTemporalController):
         template_specification['loadExistentEntityUrl'] = LOAD_EXISTING_URL
         template_specification['resetToDefaultUrl'] = RELOAD_DEFAULT_PAGE_URL
         template_specification['existentEntitiesInputList'] = self.render_spatial_form(existent_lcon_form)
-        template_specification['submit_parameters_url'] = '/spatial/localconnectivity/create_local_connectivity'
-        template_specification['equationViewerUrl'] = '/spatial/localconnectivity/get_equation_chart'
+        template_specification['submit_parameters_url'] = self.build_path('/spatial/localconnectivity/create_local_connectivity')
+        template_specification['equationViewerUrl'] = self.build_path('/spatial/localconnectivity/get_equation_chart')
         template_specification['baseUrl'] = self.base_url
 
         self.plotted_equation_prefixes = {self.SURFACE_FIELD: configure_lcon_form.surface.name,
@@ -134,18 +132,6 @@ class LocalConnectivityController(SpatioTemporalController):
         template_specification['next_step_url'] = '/spatial/localconnectivity/step_2'
         return self.fill_default_attributes(template_specification)
 
-    @cherrypy.expose
-    @using_template('form_fields/form_field')
-    @handle_error(redirect=False)
-    @check_user
-    def refresh_subform(self, equation, mapping_key):
-        eq_class = get_ui_name_to_equation_dict().get(equation)
-        current_lconn = common.get_from_session(KEY_LCONN)
-        current_lconn.equation = eq_class()
-
-        eq_params_form = SubformHelper.get_subform_for_field_value(equation, mapping_key)
-        return {'adapter_form': eq_params_form, 'equationsPrefixes': self.plotted_equation_prefixes}
-
     @cherrypy.expose
     def set_equation_param(self, **param):
         current_lconn = common.get_from_session(KEY_LCONN)
@@ -193,7 +179,7 @@ class LocalConnectivityController(SpatioTemporalController):
         template_specification['existentEntitiesInputList'] = self.render_adapter_form(left_side_form)
         template_specification['loadExistentEntityUrl'] = LOAD_EXISTING_URL
         template_specification['resetToDefaultUrl'] = RELOAD_DEFAULT_PAGE_URL
-        template_specification['next_step_url'] = '/spatial/localconnectivity/step_1'
+        template_specification['next_step_url'] = self.build_path('/spatial/localconnectivity/step_1')
         msg, _ = common.get_message_from_session()
         template_specification['displayedMessage'] = msg
         if current_lconn is not None:
@@ -268,7 +254,7 @@ class LocalConnectivityController(SpatioTemporalController):
         """
         Overwrite base controller to add required parameters for adapter templates.
         """
-        template_dictionary[common.KEY_SECTION] = 'connectivity'
+        template_dictionary[common.KEY_SECTION] = WebStructure.SECTION_CONNECTIVITY
         template_dictionary[common.KEY_SUB_SECTION] = 'local'
         template_dictionary[common.KEY_SUBMENU_LIST] = self.connectivity_submenu
         template_dictionary[common.KEY_INCLUDE_RESOURCES] = 'spatial/included_resources'
