@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -34,17 +34,17 @@
 """
 
 import json
-
+import uuid
 import cherrypy
 import numpy
-from tvb.adapters.creators.stimulus_creator import *
+from tvb.adapters.creators.stimulus_creator import KEY_REGION_STIMULUS, RegionStimulusCreatorForm, RegionStimulusCreator
+from tvb.adapters.creators.stimulus_creator import StimulusRegionSelectorForm, RegionStimulusCreatorModel
 from tvb.adapters.datatypes.h5.patterns_h5 import StimuliRegionH5
-from tvb.adapters.simulator.equation_forms import get_form_for_equation
-from tvb.adapters.simulator.subform_helper import SubformHelper
-from tvb.adapters.simulator.subforms_mapping import get_ui_name_to_equation_dict
+from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
+from tvb.adapters.forms.equation_forms import get_form_for_equation
+from tvb.adapters.forms.equation_plot_forms import EquationTemporalPlotForm
 from tvb.adapters.visualizers.connectivity import ConnectivityViewer
 from tvb.core.adapters.abcadapter import ABCAdapter
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.load import try_get_last_datatype, load_entity_by_gid
 from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
@@ -52,32 +52,11 @@ from tvb.datatypes.patterns import StimuliRegion
 from tvb.interfaces.web.controllers import common
 from tvb.interfaces.web.controllers.autologging import traced
 from tvb.interfaces.web.controllers.common import MissingDataException
-from tvb.interfaces.web.controllers.decorators import handle_error, expose_page, expose_fragment, using_template, \
-    check_user
+from tvb.interfaces.web.controllers.decorators import handle_error, expose_page, expose_fragment
 from tvb.interfaces.web.controllers.spatial.base_spatio_temporal_controller import SpatioTemporalController
-from tvb.interfaces.web.controllers.spatial.surface_model_parameters_controller import EquationPlotForm
 
-LOAD_EXISTING_URL = '/spatial/stimulus/region/load_region_stimulus'
-RELOAD_DEFAULT_PAGE_URL = '/spatial/stimulus/region/reset_region_stimulus'
-
-KEY_REGION_STIMULUS = "stim-region"
-
-
-class TemporalPlotForm(EquationPlotForm):
-    def __init__(self):
-        super(TemporalPlotForm, self).__init__()
-        self.min_x.label = 'Temporal Start Time(ms)'
-        self.min_x.doc = "The minimum value of the x-axis for temporal equation plot. " \
-                         "Not persisted, used only for visualization."
-        self.max_x.label = 'Temporal Start Time(ms)'
-        self.max_x.doc = "The maximum value of the x-axis for temporal equation plot. " \
-                         "Not persisted, used only for visualization."
-
-    def fill_from_post(self, form_data):
-        if self.min_x.name in form_data:
-            self.min_x.fill_from_post(form_data)
-        if self.max_x.name in form_data:
-            self.max_x.fill_from_post(form_data)
+LOAD_EXISTING_URL = SpatioTemporalController.build_path('/spatial/stimulus/region/load_region_stimulus')
+RELOAD_DEFAULT_PAGE_URL = SpatioTemporalController.build_path('/spatial/stimulus/region/reset_region_stimulus')
 
 
 @traced
@@ -110,19 +89,6 @@ class RegionStimulusController(SpatioTemporalController):
             current_stimulus_region = common.get_from_session(KEY_REGION_STIMULUS)
             current_stimulus_region.display_name = display_name_form_field.value
 
-    @cherrypy.expose
-    @using_template('form_fields/form_field')
-    @handle_error(redirect=False)
-    @check_user
-    def refresh_subform(self, temporal_equation, mapping_key):
-        eq_class = get_ui_name_to_equation_dict().get(temporal_equation)
-        current_region_stim = common.get_from_session(KEY_REGION_STIMULUS)
-        current_region_stim.temporal = eq_class()
-
-        eq_params_form = SubformHelper.get_subform_for_field_value(temporal_equation, mapping_key)
-        # TODO: check eqPrefixes
-        return {'adapter_form': eq_params_form, 'equationsPrefixes': self.plotted_equation_prefixes}
-
     @cherrypy.expose
     def set_temporal_param(self, **param):
         current_region_stim = common.get_from_session(KEY_REGION_STIMULUS)
@@ -166,7 +132,7 @@ class RegionStimulusController(SpatioTemporalController):
             self.DISPLAY_NAME_FIELD: region_stim_selector_form.display_name.name
         }
         template_specification['fieldsWithEvents'] = json.dumps(self.plotted_equation_prefixes)
-        template_specification['next_step_url'] = '/spatial/stimulus/region/step_1_submit'
+        template_specification['next_step_url'] = self.build_path('/spatial/stimulus/region/step_1_submit')
         template_specification['anyScaling'] = 0
         template_specification = self._add_extra_fields_to_interface(template_specification)
         return self.fill_default_attributes(template_specification)
@@ -183,7 +149,7 @@ class RegionStimulusController(SpatioTemporalController):
 
         template_specification = dict(title="Spatio temporal - Region stimulus")
         template_specification['mainContent'] = 'spatial/stimulus_region_step2_main'
-        template_specification['next_step_url'] = '/spatial/stimulus/region/step_2_submit'
+        template_specification['next_step_url'] = self.build_path('/spatial/stimulus/region/step_2_submit')
         template_specification['regionStimSelectorForm'] = self.render_adapter_form(region_stim_selector_form)
 
         default_weights = current_region_stimulus.weight
@@ -223,7 +189,7 @@ class RegionStimulusController(SpatioTemporalController):
 
     def _reset_region_stimulus(self):
         new_region_stimulus = RegionStimulusCreatorModel()
-        new_region_stimulus.temporal = RegionStimulusCreatorForm.default_temporal()
+        new_region_stimulus.temporal = RegionStimulusCreatorForm.default_temporal.instance
         # TODO: proper init
         new_region_stimulus.weight = numpy.array([])
         common.add2session(KEY_REGION_STIMULUS, new_region_stimulus)
@@ -255,8 +221,8 @@ class RegionStimulusController(SpatioTemporalController):
         if connectivity is None:
             raise MissingDataException(RegionStimulusController.MSG_MISSING_CONNECTIVITY + "!!")
         current_project = common.get_current_project()
-        conn_path = FilesHelper().get_project_folder(current_project, str(connectivity.fk_from_operation))
-        connectivity_viewer_params = ConnectivityViewer.get_connectivity_parameters(connectivity, conn_path)
+        connectivity_viewer_params = ConnectivityViewer.get_connectivity_parameters(connectivity, current_project.name,
+                                                                                    str(connectivity.fk_from_operation))
 
         template_specification = dict()
         template_specification['isSingleMode'] = True
@@ -294,11 +260,11 @@ class RegionStimulusController(SpatioTemporalController):
         Returns the html which contains the plot with the temporal equation.
         """
         try:
-            plot_form = TemporalPlotForm()
+            plot_form = EquationTemporalPlotForm()
             if form_data:
                 plot_form.fill_from_post(form_data)
 
-            min_x, max_x, ui_message = self.get_x_axis_range(plot_form.min_x.value, plot_form.max_x.value)
+            min_x, max_x, ui_message = self.get_x_axis_range(plot_form.min_tmp_x.value, plot_form.max_tmp_x.value)
             current_stimuli_region = common.get_from_session(KEY_REGION_STIMULUS)
             series_data, display_ui_message = current_stimuli_region.temporal.get_series_data(min_range=min_x,
                                                                                               max_range=max_x)
@@ -361,7 +327,7 @@ class RegionStimulusController(SpatioTemporalController):
         The fields that have to be added to the existent
         adapter interface should be added in this method.
         """
-        temporal_plot_list_form = TemporalPlotForm()
+        temporal_plot_list_form = EquationTemporalPlotForm()
         input_list['temporalPlotInputList'] = self.render_adapter_form(temporal_plot_list_form)
         return input_list
 
