@@ -40,11 +40,10 @@ import json
 import os
 import ssl
 import time
-from urllib.request import urlopen
-
 import cherrypy
 import formencode
 import tvb.interfaces.web
+from urllib.request import urlopen
 from formencode import validators
 from tvb.basic.profile import TvbProfile
 from tvb.core.entities.file.files_update_manager import FilesUpdateManager
@@ -59,6 +58,7 @@ from tvb.interfaces.web.controllers.base_controller import BaseController
 from tvb.interfaces.web.controllers.decorators import check_user, expose_json, check_admin
 from tvb.interfaces.web.controllers.decorators import handle_error, using_template, settings, jsonify
 from tvb.interfaces.web.entities.context_simulator import SimulatorContext
+from tvb.interfaces.web.structure import WebStructure
 from tvb.storage.storage_interface import StorageInterface
 
 KEY_SERVER_VERSION = "versionInfo"
@@ -95,6 +95,7 @@ class UserController(BaseController):
                     kc_user_info = AuthorizationManager(
                         TvbProfile.current.KEYCLOAK_WEB_CONFIG).get_keycloak_instance().userinfo(auth_token)
                     user = self.user_service.get_external_db_user(kc_user_info)
+                    setattr(user, KEY_AUTH_TOKEN, auth_token)
                 else:
                     username = data[KEY_USERNAME]
                     password = data[KEY_PASSWORD]
@@ -107,7 +108,7 @@ class UserController(BaseController):
                         prj = user.selected_project
                         prj = self.project_service.find_project(prj)
                         self._mark_selected(prj)
-                    raise cherrypy.HTTPRedirect('/user/profile')
+                    self.redirect('/user/profile')
                 elif not keycloak_login:
                     common.set_error_message('Wrong username/password, or user not yet validated...')
                     self.logger.debug("Wrong username " + username + " !!!")
@@ -132,7 +133,7 @@ class UserController(BaseController):
         On POST: logout, or save password/email.
         """
         if cherrypy.request.method == 'POST' and logout:
-            raise cherrypy.HTTPRedirect('/user/logout')
+            self.redirect('/user/logout')
         template_specification = dict(mainContent="user/profile", title="User Profile")
         user = common.get_logged_user()
 
@@ -159,10 +160,6 @@ class UserController(BaseController):
                 user = common.get_logged_user()
                 common.add2session(common.KEY_USER, self.user_service.get_user_by_id(user.id))
                 common.set_error_message("Could not save changes. Probably wrong old password!!")
-        else:
-            # Update session user since disk size might have changed from last time to profile.
-            user = self.user_service.get_user_by_id(user.id)
-            common.add2session(common.KEY_USER, user)
 
         template_specification['user_used_disk_human'] = format_bytes_human(
             self.user_service.compute_user_generated_disk_size(user.id))
@@ -191,7 +188,7 @@ class UserController(BaseController):
         common.set_info_message("Thank you for using The Virtual Brain!")
 
         common.expire_session()
-        raise cherrypy.HTTPRedirect("/user")
+        self.redirect("/user")
 
     @cherrypy.expose
     @handle_error(redirect=False)
@@ -213,7 +210,7 @@ class UserController(BaseController):
         # Change OnlineHelp Active flag and save user
         user.switch_online_help_state()
         self.user_service.edit_user(user)
-        raise cherrypy.HTTPRedirect("/user/profile")
+        self.redirect("/user/profile")
 
     @expose_json
     def get_viewer_color_scheme(self):
@@ -243,7 +240,7 @@ class UserController(BaseController):
         redirect = False
         if cherrypy.request.method == 'POST':
             if cancel:
-                raise cherrypy.HTTPRedirect('/user')
+                self.redirect('/user')
             try:
                 okmessage = self._create_user(**data)
                 common.set_info_message(okmessage)
@@ -260,7 +257,7 @@ class UserController(BaseController):
 
         if redirect:
             # Redirect to login page, with some success message to display
-            raise cherrypy.HTTPRedirect('/user')
+            self.redirect('/user')
         else:
             # Stay on the same page
             return self.fill_default_attributes(template_specification)
@@ -273,7 +270,7 @@ class UserController(BaseController):
         Create new user with data submitted from UI.
         """
         if cancel:
-            raise cherrypy.HTTPRedirect('/user/usermanagement')
+            self.redirect('/user/usermanagement')
         template_specification = dict(mainContent="user/create_new", title="Create New", data=data)
         redirect = False
         if cherrypy.request.method == 'POST':
@@ -295,7 +292,7 @@ class UserController(BaseController):
                 common.set_error_message("We are very sorry, but we could not create your user. Most probably is "
                                          "because it was impossible to send emails. Please try again later...")
         if redirect:
-            raise cherrypy.HTTPRedirect('/user/usermanagement')
+            self.redirect('/user/usermanagement')
         else:
             return self.fill_default_attributes(template_specification)
 
@@ -308,7 +305,7 @@ class UserController(BaseController):
         Display a table used for user management.
         """
         if cancel:
-            raise cherrypy.HTTPRedirect('/user/profile')
+            self.redirect('/user/profile')
 
         page = int(page)
         if cherrypy.request.method == 'POST' and do_persist:
@@ -353,7 +350,7 @@ class UserController(BaseController):
         redirect = False
         if cherrypy.request.method == 'POST':
             if cancel:
-                raise cherrypy.HTTPRedirect('/user')
+                self.redirect('/user')
             form = RecoveryForm()
             try:
                 data = form.to_python(data)
@@ -369,7 +366,7 @@ class UserController(BaseController):
                 redirect = False
         if redirect:
             # Redirect to login page, with some success message to display
-            raise cherrypy.HTTPRedirect('/user')
+            self.redirect('/user')
         else:
             # Stay on the same page
             return self.fill_default_attributes(template_specification)
@@ -400,12 +397,14 @@ class UserController(BaseController):
             self.logger.error("Problem validating user " + name)
         else:
             common.set_info_message("User Validated successfully and notification email sent!")
-        raise cherrypy.HTTPRedirect('/tvb')
+        self.redirect('/tvb')
 
     @cherrypy.expose
     def base_url(self, **data):
         if not TvbProfile.current.web.BASE_URL:
             url = data['url']
+            if TvbProfile.current.web.DEPLOY_CONTEXT:
+                url += TvbProfile.current.web.DEPLOY_CONTEXT
             self.logger.info("Set base url to {}".format(url))
             TvbProfile.current.web.BASE_URL = url
 
@@ -428,6 +427,7 @@ class UserController(BaseController):
         template_dictionary[common.KEY_INCLUDE_TOOLTIP] = True
         template_dictionary[common.KEY_WRAP_CONTENT_IN_MAIN_DIV] = False
         template_dictionary[common.KEY_CURRENT_TAB] = 'nav-user'
+        template_dictionary[common.KEY_SECTION] = WebStructure.SECTION_USER
         template_dictionary[KEY_STORAGE_IN_UPDATE] = (TvbProfile.current.version.DATA_CHECKED_TO_VERSION <
                                                       TvbProfile.current.version.DATA_VERSION)
         return template_dictionary
