@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -35,28 +35,25 @@ Launches the web server and configure the controllers for UI.
 """
 import time
 
-from tvb.core.entities.file.data_encryption_handler import encryption_handler, FoldersQueueConsumer, \
-    DataEncryptionHandler
 
 STARTUP_TIC = time.time()
 
 import os
 import importlib
-from subprocess import Popen, PIPE
 import sys
 import webbrowser
-
 import cherrypy
 from cherrypy import Tool
 from cherrypy.lib.sessions import RamSession
+from subprocess import Popen, PIPE
 from tvb.basic.logger.builder import get_logger
 from tvb.basic.profile import TvbProfile
 from tvb.config.init.initializer import initialize, reset
 from tvb.core.adapters.abcdisplayer import ABCDisplayer
 from tvb.core.decorators import user_environment_execution
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.services.exceptions import InvalidSettingsException
 from tvb.core.services.hpc_operation_service import HPCOperationService
+from tvb.core.services.backend_clients.standalone_client import StandAloneClient
 from tvb.interfaces.web.controllers.base_controller import BaseController
 from tvb.interfaces.web.controllers.burst.dynamic_model_controller import DynamicModelController
 from tvb.interfaces.web.controllers.burst.exploration_controller import ParameterExplorationController
@@ -66,6 +63,7 @@ from tvb.interfaces.web.controllers.common import KEY_PROJECT
 from tvb.interfaces.web.controllers.flow_controller import FlowController
 from tvb.interfaces.web.controllers.help.help_controller import HelpController
 from tvb.interfaces.web.controllers.hpc_controller import HPCController
+from tvb.interfaces.web.controllers.kube_controller import KubeController
 from tvb.interfaces.web.controllers.project.figure_controller import FigureController
 from tvb.interfaces.web.controllers.project.project_controller import ProjectController
 from tvb.interfaces.web.controllers.settings_controller import SettingsController
@@ -75,11 +73,16 @@ from tvb.interfaces.web.controllers.spatial.local_connectivity_controller import
 from tvb.interfaces.web.controllers.spatial.region_stimulus_controller import RegionStimulusController
 from tvb.interfaces.web.controllers.spatial.surface_model_parameters_controller import SurfaceModelParametersController
 from tvb.interfaces.web.controllers.spatial.surface_stimulus_controller import SurfaceStimulusController
+from tvb.interfaces.web.controllers.burst.transfer_vector_controller import TransferVectorController
 from tvb.interfaces.web.controllers.users_controller import UserController
 from tvb.interfaces.web.request_handler import RequestHandler
+from tvb.storage.storage_interface import StorageInterface
 
 if __name__ == '__main__':
-    TvbProfile.set_profile(sys.argv[1])
+    if len(sys.argv) < 2:
+        TvbProfile.set_profile(TvbProfile.WEB_PROFILE)
+    else:
+        TvbProfile.set_profile(sys.argv[1])
 
 LOGGER = get_logger('tvb.interfaces.web.run')
 CONFIG_EXISTS = not TvbProfile.is_first_run()
@@ -90,7 +93,6 @@ LOGGER.info("TVB application will be running using encoding: " + sys.getdefaulte
 class CleanupSessionHandler(RamSession):
     def __init__(self, id=None, **kwargs):
         super(CleanupSessionHandler, self).__init__(id, **kwargs)
-        self.file_helper = FilesHelper()
 
     def clean_up(self):
         """Clean up expired sessions."""
@@ -100,7 +102,7 @@ class CleanupSessionHandler(RamSession):
             if expiration_time <= now:
                 if KEY_PROJECT in data:
                     selected_project = data[KEY_PROJECT]
-                    encryption_handler.set_project_inactive(selected_project)
+                    StorageInterface().set_project_inactive(selected_project)
                 try:
                     del self.cache[_id]
                 except KeyError:
@@ -124,10 +126,10 @@ class CleanupSessionHandler(RamSession):
 
 
 def init_cherrypy(arguments=None):
-    #### Mount static folders from modules marked for introspection
+    # Mount static folders from modules marked for introspection
     arguments = arguments or []
     CONFIGUER = TvbProfile.current.web.CHERRYPY_CONFIGURATION
-    if DataEncryptionHandler.encryption_enabled():
+    if StorageInterface.encryption_enabled():
         CONFIGUER["/"]["tools.sessions.storage_class"] = CleanupSessionHandler
     for module in arguments:
         module_inst = importlib.import_module(str(module))
@@ -136,25 +138,35 @@ def init_cherrypy(arguments=None):
                                                'tools.staticdir.dir': '.',
                                                'tools.staticdir.root': module_path}
 
-    #### Mount controllers, and specify the root URL for them.
-    cherrypy.tree.mount(BaseController(), "/", config=CONFIGUER)
-    cherrypy.tree.mount(UserController(), "/user/", config=CONFIGUER)
-    cherrypy.tree.mount(ProjectController(), "/project/", config=CONFIGUER)
-    cherrypy.tree.mount(FigureController(), "/project/figure/", config=CONFIGUER)
-    cherrypy.tree.mount(FlowController(), "/flow/", config=CONFIGUER)
-    cherrypy.tree.mount(SettingsController(), "/settings/", config=CONFIGUER)
-    cherrypy.tree.mount(HelpController(), "/help/", config=CONFIGUER)
-    cherrypy.tree.mount(SimulatorController(), "/burst/", config=CONFIGUER)
-    cherrypy.tree.mount(ParameterExplorationController(), "/burst/explore/", config=CONFIGUER)
-    cherrypy.tree.mount(DynamicModelController(), "/burst/dynamic/", config=CONFIGUER)
-    cherrypy.tree.mount(SpatioTemporalController(), "/spatial/", config=CONFIGUER)
-    cherrypy.tree.mount(RegionsModelParametersController(), "/burst/modelparameters/regions/", config=CONFIGUER)
-    cherrypy.tree.mount(SurfaceModelParametersController(), "/spatial/modelparameters/surface/", config=CONFIGUER)
-    cherrypy.tree.mount(RegionStimulusController(), "/spatial/stimulus/region/", config=CONFIGUER)
-    cherrypy.tree.mount(SurfaceStimulusController(), "/spatial/stimulus/surface/", config=CONFIGUER)
-    cherrypy.tree.mount(LocalConnectivityController(), "/spatial/localconnectivity/", config=CONFIGUER)
-    cherrypy.tree.mount(NoiseConfigurationController(), "/burst/noise/", config=CONFIGUER)
-    cherrypy.tree.mount(HPCController(), "/hpc/", config=CONFIGUER)
+    # Mount controllers, and specify the root URL for them.
+    cherrypy.tree.mount(BaseController(), BaseController.build_path("/"), config=CONFIGUER)
+    cherrypy.tree.mount(UserController(), BaseController.build_path("/user/"), config=CONFIGUER)
+    cherrypy.tree.mount(ProjectController(), BaseController.build_path("/project/"), config=CONFIGUER)
+    cherrypy.tree.mount(FigureController(), BaseController.build_path("/project/figure/"), config=CONFIGUER)
+    cherrypy.tree.mount(FlowController(), BaseController.build_path("/flow/"), config=CONFIGUER)
+    cherrypy.tree.mount(SettingsController(), BaseController.build_path("/settings/"), config=CONFIGUER)
+    cherrypy.tree.mount(HelpController(), BaseController.build_path("/help/"), config=CONFIGUER)
+    cherrypy.tree.mount(SimulatorController(), BaseController.build_path("/burst/"), config=CONFIGUER)
+    cherrypy.tree.mount(ParameterExplorationController(), BaseController.build_path("/burst/explore/"),
+                        config=CONFIGUER)
+    cherrypy.tree.mount(DynamicModelController(), BaseController.build_path("/burst/dynamic/"), config=CONFIGUER)
+    cherrypy.tree.mount(SpatioTemporalController(), BaseController.build_path("/spatial/"), config=CONFIGUER)
+    cherrypy.tree.mount(RegionsModelParametersController(),
+                        BaseController.build_path("/burst/modelparameters/regions/"),
+                        config=CONFIGUER)
+    cherrypy.tree.mount(SurfaceModelParametersController(),
+                        BaseController.build_path("/spatial/modelparameters/surface/"),
+                        config=CONFIGUER)
+    cherrypy.tree.mount(RegionStimulusController(), BaseController.build_path("/spatial/stimulus/region/"),
+                        config=CONFIGUER)
+    cherrypy.tree.mount(SurfaceStimulusController(), BaseController.build_path("/spatial/stimulus/surface/"),
+                        config=CONFIGUER)
+    cherrypy.tree.mount(LocalConnectivityController(), BaseController.build_path("/spatial/localconnectivity/"),
+                        config=CONFIGUER)
+    cherrypy.tree.mount(NoiseConfigurationController(), BaseController.build_path("/burst/noise/"), config=CONFIGUER)
+    cherrypy.tree.mount(TransferVectorController(), TransferVectorController.build_path("/burst/transfer/"), config=CONFIGUER)
+    cherrypy.tree.mount(HPCController(), BaseController.build_path("/hpc/"), config=CONFIGUER)
+    cherrypy.tree.mount(KubeController(), BaseController.build_path("/kube/"), config=CONFIGUER)
 
     cherrypy.config.update(CONFIGUER)
 
@@ -171,7 +183,13 @@ def init_cherrypy(arguments=None):
             TvbProfile.current.hpc.BACKGROUND_JOB_INTERVAL, HPCOperationService.check_operations_job)
         cherrypy.engine.housekeeper.start()
 
-    # HTTP Server is fired now ######
+    if not TvbProfile.current.web.OPENSHIFT_DEPLOY:
+        operations_job = cherrypy.process.plugins.BackgroundTask(
+            TvbProfile.current.OPERATIONS_BACKGROUND_JOB_INTERVAL, StandAloneClient.process_queued_operations,
+            bus=cherrypy.engine)
+        operations_job.start()
+
+    # HTTP Server is fired now #
     cherrypy.engine.start()
 
 
@@ -181,7 +199,8 @@ def expose_rest_api():
         return
 
     if not os.path.exists(TvbProfile.current.KEYCLOAK_CONFIG):
-        LOGGER.warning("Cannot start REST server because the KEYCLOAK CONFIG file {} does not exist.".format(TvbProfile.current.KEYCLOAK_CONFIG))
+        LOGGER.warning("Cannot start REST server because the KEYCLOAK CONFIG file {} does not exist.".format(
+            TvbProfile.current.KEYCLOAK_CONFIG))
         return
 
     if CONFIG_EXISTS:
@@ -202,7 +221,7 @@ def start_tvb(arguments, browser=True):
     """
 
     if PARAM_RESET_DB in arguments:
-        ##### When specified, clean everything in DB
+        # When specified, clean everything in DB
         reset()
         arguments.remove(PARAM_RESET_DB)
 
@@ -218,22 +237,22 @@ def start_tvb(arguments, browser=True):
         LOGGER.exception(excep)
         sys.exit()
 
-    #### Mark that the interface is Web
+    # Mark that the interface is Web
     ABCDisplayer.VISUALIZERS_ROOT = TvbProfile.current.web.VISUALIZERS_ROOT
 
     init_cherrypy(arguments)
-    if DataEncryptionHandler.encryption_enabled():
-        queue_consumer = FoldersQueueConsumer()
-        queue_consumer.start()
-        DataEncryptionHandler.startup_cleanup()
+    if StorageInterface.encryption_enabled() and StorageInterface.app_encryption_handler():
+        storage_interface = StorageInterface()
+        storage_interface.start()
+        storage_interface.startup_cleanup()
 
-    #### Fire a browser page at the end.
+    # Fire a browser page at the end.
     if browser:
         run_browser()
 
     expose_rest_api()
 
-    ## Launch CherryPy loop forever.
+    # Launch CherryPy loop forever.
     LOGGER.info("Finished starting TVB version %s in %.3f s",
                 TvbProfile.current.version.CURRENT_VERSION, time.time() - STARTUP_TIC)
     cherrypy.engine.block()
@@ -263,6 +282,6 @@ def run_browser():
 
 
 if __name__ == '__main__':
-    #### Prepare parameters and fire CherryPy
-    #### Remove not-relevant parameter, 0 should point towards this "run.py" file, 1 to the profile
+    # Prepare parameters and fire CherryPy
+    # Remove not-relevant parameter, 0 should point towards this "run.py" file, 1 to the profile
     start_tvb(sys.argv[2:])
