@@ -141,8 +141,8 @@ function renderAllSimulatorForms(url, stop_at_url = '', onFinishFunction = null)
             url: url,
             success: function (response) {
                 const t = document.createRange().createContextualFragment(response);
-                simulator_params.appendChild(t);
-                MathJax.Hub.Queue(["Typeset", MathJax.Hub, "div-simulator-parameters"]);
+                renderWithMathjax(simulator_params, t);
+
 
                 const next_url = $(response).attr("action");
                 if (next_url && next_url.length > 0) {
@@ -170,9 +170,7 @@ function loadBurstHistory(initBurst = false) {
         async: false,
         success: function (r) {
             const historyElem = $('#section-view-history');
-            historyElem.empty();
-            historyElem.append(r);
-            MathJax.Hub.Queue(["Typeset", MathJax.Hub, "section-view-history"]);
+            renderWithMathjax(historyElem, r, true);
             //setupMenuEvents(historyElem);
         },
         error: function () {
@@ -361,6 +359,10 @@ function configureNoiseParameters() {
     configureModel("/burst/noise/");
 }
 
+function applyTransferFunction(){
+    configureModel("/burst/transfer");
+}
+
 function toggleConfigSurfaceModelParamsButton() {
     var selectorSurfaceElem = $("select[name='surface']");
     selectorSurfaceElem.unbind('change.configureSurfaceModelParameters');
@@ -638,24 +640,25 @@ function setInitialFocusOnButton(simulator_params) {
 
 function previousWizzardStep(currentForm, previous_action, div_id = 'div-simulator-parameters') {
     $.ajax({
-        url: '/burst/set_fragment_url',
+        url: deploy_context + '/burst/set_fragment_url',
         type: 'POST',
         data: {"url": previous_action},
     });
     const simulator_params = document.getElementById(div_id);
     simulator_params.removeChild(currentForm);
 
-    var previous_form = document.getElementById(previous_action);
-    var next_button = previous_form.elements.namedItem('next');
-    var previous_button = previous_form.elements.namedItem('previous');
-    var config_region_param_button = previous_form.elements.namedItem('configRegionModelParam');
-    var config_surface_param_button = previous_form.elements.namedItem('configSurfaceModelParam');
-    var config_noise_button = previous_form.elements.namedItem('configNoiseValues');
-    var config_launch_button = previous_form.elements.namedItem('launch_simulation');
-    var config_pse_button = previous_form.elements.namedItem('setup_pse');
-    var config_launch_pse_button = previous_form.elements.namedItem('launch_pse');
-    var config_branch_button = previous_form.elements.namedItem('branch_simulation');
-    var fieldset = previous_form.elements[0];
+    const previous_form = document.getElementById(previous_action);
+    const next_button = previous_form.elements.namedItem('next');
+    const previous_button = previous_form.elements.namedItem('previous');
+    const config_region_param_button = previous_form.elements.namedItem('configRegionModelParam');
+    const apply_transfer_function_button = previous_form.elements.namedItem('configSpatialVector');
+    const config_surface_param_button = previous_form.elements.namedItem('configSurfaceModelParam');
+    const config_noise_button = previous_form.elements.namedItem('configNoiseValues');
+    const config_launch_button = previous_form.elements.namedItem('launch_simulation');
+    const config_pse_button = previous_form.elements.namedItem('setup_pse');
+    const config_launch_pse_button = previous_form.elements.namedItem('launch_pse');
+    const config_branch_button = previous_form.elements.namedItem('branch_simulation');
+    const fieldset = previous_form.elements[0];
 
     if (next_button != null) {
         next_button.style.visibility = 'visible';
@@ -666,6 +669,9 @@ function previousWizzardStep(currentForm, previous_action, div_id = 'div-simulat
     if (config_region_param_button != null) {
         config_region_param_button.style.visibility = 'visible';
     }
+    if(apply_transfer_function_button != null){
+        apply_transfer_function_button.style.visibility = 'visible';
+    }
     if (config_surface_param_button != null) {
         config_surface_param_button.style.visibility = 'visible';
     }
@@ -708,19 +714,20 @@ function wizzard_submit(currentForm, success_function = null, div_id = 'div-simu
     if (disabledFieldset){
         $(fieldset).attr('disabled', 'disabled')
     }
-    var next_button = currentForm.elements.namedItem('next');
-    var previous_button = currentForm.elements.namedItem('previous');
-    var config_region_param_button = currentForm.elements.namedItem('configRegionModelParam');
-    var config_surface_param_button = currentForm.elements.namedItem('configSurfaceModelParam');
-    var config_noise_button = currentForm.elements.namedItem('configNoiseValues');
-    var config_launch_button = currentForm.elements.namedItem('launch_simulation');
-    var config_pse_button = currentForm.elements.namedItem('setup_pse');
-    var config_launch_pse_button = currentForm.elements.namedItem('launch_pse');
-    var config_branch_button = currentForm.elements.namedItem('branch_simulation');
+    const next_button = currentForm.elements.namedItem('next');
+    const previous_button = currentForm.elements.namedItem('previous');
+    const config_region_param_button = currentForm.elements.namedItem('configRegionModelParam');
+    const apply_transfer_function_button = currentForm.elements.namedItem('configSpatialVector');
+    const config_surface_param_button = currentForm.elements.namedItem('configSurfaceModelParam');
+    const config_noise_button = currentForm.elements.namedItem('configNoiseValues');
+    const config_launch_button = currentForm.elements.namedItem('launch_simulation');
+    const config_pse_button = currentForm.elements.namedItem('setup_pse');
+    const config_launch_pse_button = currentForm.elements.namedItem('launch_pse');
+    const config_branch_button = currentForm.elements.namedItem('branch_simulation');
     var fieldset = currentForm.elements[0];
 
     $.ajax({
-        url: post_url,
+        url: deploy_context + post_url,
         type: request_method,
         data: form_data,
         success: function (response) {
@@ -736,6 +743,9 @@ function wizzard_submit(currentForm, success_function = null, div_id = 'div-simu
                 if (config_region_param_button != null) {
                     config_region_param_button.style.visibility = 'hidden';
                 }
+                if(apply_transfer_function_button != null){
+                    apply_transfer_function_button.style.visibility = 'hidden';
+                }
                 if (config_surface_param_button != null) {
                     config_surface_param_button.style.visibility = 'hidden';
                 }
@@ -755,10 +765,9 @@ function wizzard_submit(currentForm, success_function = null, div_id = 'div-simu
                     config_branch_button.style.visibility = 'hidden';
                 }
                 fieldset.disabled = true;
-                var t = document.createRange().createContextualFragment(response);
+                const t = document.createRange().createContextualFragment(response);
                 const simulator_params = document.getElementById(div_id);
-                simulator_params.appendChild(t);
-                MathJax.Hub.Queue(["Typeset", MathJax.Hub, div_id]);
+                renderWithMathjax(simulator_params, t);
                 setInitialFocusOnButton(simulator_params);
                 setupMenuEvents();
             }
