@@ -418,13 +418,11 @@ function onModelChanged(name){
             data = JSON.parse(data);
 
             var sliderContainer = $('#div_spatial_model_params');
-            sliderContainer.html(data.model_param_sliders_fragment);
-            MathJax.Hub.Queue(["Typeset", MathJax.Hub, 'div_spatial_model_params']);
+            renderWithMathjax(sliderContainer, data.model_param_sliders_fragment, true);
             setupMenuEvents(sliderContainer);
 
             var axisSliderContainer = $('#div_phase_plane_settings');
-            axisSliderContainer.html(data.axis_sliders_fragment);
-            MathJax.Hub.Queue(["Typeset", MathJax.Hub, 'div_phase_plane_settings']);
+            renderWithMathjax(axisSliderContainer, data.axis_sliders_fragment, true);
             setupMenuEvents(axisSliderContainer);
 
             _initialize_grafic(data.params, data.graph_params);
@@ -504,7 +502,7 @@ dynamicPage.main = main;
 
 function setIntegratorParamAndRedrawChart(methodToCall, fieldName, fieldValue, type) {
     let currentParam = fieldName + '=' + fieldValue;
-    let url = methodToCall + '/' + dynamicPage.dynamic_gid + '/' + type + '?' + currentParam;
+    let url = deploy_context + methodToCall + '/' + dynamicPage.dynamic_gid + '/' + type + '?' + currentParam;
     $.ajax({
         url: url,
         type: 'POST',
