@@ -133,6 +133,14 @@ function fireOnClick(redirectElem) {
     }
 }
 
+// ---------- Function for rendering HTML elements with Mathjax
+function renderWithMathjax(element, elementToAppend, empty=false){
+    if(empty){
+        element.empty();
+    }
+    element.append(elementToAppend);
+    MathJax.Hub.Queue(["Typeset", MathJax.Hub, element.id]);
+}
 
 // ---------- Function on the top left call-out
 function updateCallOutProject() {
@@ -326,17 +334,6 @@ function validateDb(db_url, tvb_storage) {
     });
 }
 
-function validateMatlabPath(matlab_path) {
-    const matlab_path_value = document.getElementById(matlab_path).value;
-    doAjaxCall({
-        async: false,
-        type: 'GET',
-        url: "/settings/validate_matlab_path",
-        data: {MATLAB_EXECUTABLE: matlab_path_value},
-        success: _on_validation_finished
-    });
-}
-
 function changeDBValue(selectComponent) {
     const component = eval(selectComponent);
     const selectedValue = $(component).val();
@@ -371,7 +368,7 @@ function settingsPageInitialize() {
 // ---------------------------------------------------------
 
 function viewProject(projectId, formId) {
-    document.getElementById(formId).action = "/project/editone/" + projectId;
+    document.getElementById(formId).action = deploy_context + "/project/editone/" + projectId;
     document.getElementById(formId).submit();
 }
 
@@ -382,12 +379,12 @@ function selectProject(projectId, formId) {
 }
 
 function exportProject(projectId) {
-    window.location = "/project/downloadproject/?project_id=" + projectId
+    window.location = deploy_context + "/project/downloadproject/?project_id=" + projectId
 }
 
 function removeProject(projectId, formId) {
     const form = document.getElementById(formId);
-    form.action = "/project/editone/" + projectId + "/?delete=Delete";
+    form.action = deploy_context + "/project/editone/" + projectId + "/?delete=Delete";
     form.submit();
 }
 
@@ -509,7 +506,7 @@ function overlayRemoveEntity(projectId, dataGid, backPage) {
  * Used from Operation-Overlay and View All Operations button/each row.
  */
 function reloadOperation(operationId, formId) {
-    document.getElementById(formId).action = "/flow/reloadoperation/" + operationId;
+    document.getElementById(formId).action = deploy_context + "/flow/reloadoperation/" + operationId;
     document.getElementById(formId).submit();
 }
 
@@ -519,7 +516,7 @@ function reloadOperation(operationId, formId) {
  * burst page with that given burst as the selected one.
  */
 function reloadBurstOperation(operationId, isGroup, formId) {
-    document.getElementById(formId).action = "/flow/reload_burst_operation/" + operationId + '/' + isGroup;
+    document.getElementById(formId).action = deploy_context + "/flow/reload_burst_operation/" + operationId + '/' + isGroup;
     document.getElementById(formId).submit();
 }
 
@@ -588,7 +585,7 @@ function setOperationRelevant(operationGID, isGroup, toBeRelevant, submitFormId)
 
 function cancelOrRemoveOperation(operationId, isGroup, removeAfter) {
 
-    let urlBase = "/flow/cancel_or_remove_operation/"+ operationId + '/' + isGroup;
+    let urlBase = "/flow/cancel_or_remove_operation/" + operationId + '/' + isGroup;
     if (removeAfter) {
         urlBase += '/True';
     }
@@ -670,7 +667,7 @@ function showOverlay(url, allowClose, message_data) {
     $.ajax({
         async: false,
         type: 'GET',
-        url: url,
+        url: deploy_context + url,
         dataType: 'html',
         cache: true,
         data: message_data,
@@ -795,8 +792,10 @@ function showQuestionOverlay(question, yesCallback, noCallback) {
         noCallback = 'closeOverlay()';
     }
     const url = "/project/show_confirmation_overlay";
-    const data = {'yes_action': yesCallback,
-                  'no_action': noCallback};
+    const data = {
+        'yes_action': yesCallback,
+        'no_action': noCallback
+    };
     if (question !== null) {
         data['question'] = question;
     }
@@ -902,7 +901,7 @@ function zoomInFigure(figure_id) {
 
 
 function displayFiguresForSession(selected_session) {
-    const actionUrl = "/project/figure/displayresultfigures/" + selected_session;
+    const actionUrl = deploy_context + "/project/figure/displayresultfigures/" + selected_session;
     const myForm = document.createElement("form");
     myForm.method = "POST";
     myForm.action = actionUrl;
@@ -968,7 +967,7 @@ function doAjaxCall(params) {
 
     // Do AJAX call
     $.ajax({
-        url: params.url,
+        url: deploy_context + params.url,
         type: params.type,
         async: params.async,
         success: [onSuccess, closeOverlay],
@@ -989,7 +988,7 @@ function HLPR_readJSONfromFile(fileName, staticFiles) {
     doAjaxCall({
         async: false,
         url: fileName,
-        methos: "GET",
+        method: "GET",
         mimeType: "text/plain",
         success: function (r) {
             fileData = r;
@@ -1108,7 +1107,7 @@ function HLPR_fetchNdArray(binary_url, onload, kwargs) {
 // -------------End Binary transport parsing ----------------------------------
 
 function checkArg(arg, def) {
-    return ( typeof arg === 'undefined' ? def : arg);
+    return (typeof arg === 'undefined' ? def : arg);
 }
 
 /**
@@ -1195,14 +1194,22 @@ function prepareUrlParam(paramName, paramValue) {
     return paramName + '=' + paramValue;
 }
 
-function refreshSubform(currentElem, elementType, subformDiv) {
-    let url = prepareRefreshSubformUrl(currentElem, subformDiv);
+function prepareRefreshSubformUrl(currentElem, subformDiv, sessionKey, formKey) {
+    return '/flow/refresh_subform/' + currentElem.value + "/" + formKey + "/" + sessionKey;
+}
+
+function refreshSubform(currentElem, elementType, subformDiv, sessionKey, formKey) {
+    let url = prepareRefreshSubformUrl(currentElem, subformDiv, sessionKey, formKey);
+    if (url.startsWith('/')) {
+        url = deploy_context + url
+    }
+
     $.ajax({
         url: url,
         type: 'POST',
         success: function (r) {
-            $('#' + subformDiv).html(r);
-            MathJax.Hub.Queue(["Typeset", MathJax.Hub, subformDiv]);
+            const subform = $('#' + subformDiv);
+            renderWithMathjax(subform, r, true);
             setEventsOnFormFields(elementType, subformDiv);
             setupMenuEvents();
             plotEquation(subformDiv);
