@@ -4,7 +4,7 @@
  * TheVirtualBrain-Scientific Package (for simulators). See content of the
  * documentation-folder for more details. See also http://www.thevirtualbrain.org
  *
- * (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+ * (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
  *
  * This program is free software: you can redistribute it and/or modify it under the
  * terms of the GNU General Public License as published by the Free Software Foundation,
@@ -37,10 +37,10 @@ function setStimulusParamAndRedrawChart(methodToCall, fieldName, fieldValue) {
 }
 
 function redrawPlotOnMinMaxChanges() {
-    $('#min_x').change(function () {
+    $('#min_tmp_x').change(function () {
         plotEquation();
     });
-    $('#max_x').change(function () {
+    $('#max_tmp_x').change(function () {
         plotEquation();
     });
 }
@@ -64,10 +64,10 @@ function setEventsOnFormFields(fieldsWithEvents, div_id = 'temporal_params') {
 }
 
 function prepareUrlParams() {
-    min_field = $('#min_x')[0];
+    min_field = $('#min_tmp_x')[0];
     min_params = prepareUrlParam(min_field.name, min_field.value);
 
-    max_field = $('#max_x')[0];
+    max_field = $('#max_tmp_x')[0];
     max_params = prepareUrlParam(max_field.name, max_field.value);
 
     params = min_params + '&' + max_params;
@@ -89,7 +89,3 @@ function plotEquation(subformDiv = null) {
         }
     });
 }
-
-function prepareRefreshSubformUrl(currentElem, elementType, subformDiv) {
-    return refreshBaseUrl + '/refresh_subform/' + currentElem.value + '/' + elementType;
-}
\ No newline at end of file
