@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -42,7 +42,6 @@ from tvb.adapters.datatypes.db.region_mapping import RegionVolumeMappingIndex
 from tvb.adapters.datatypes.db.structural import StructuralMRIIndex
 from tvb.adapters.datatypes.db.time_series import TimeSeriesVolumeIndex
 from tvb.adapters.uploaders.nifti_importer import NIFTIImporterModel, NIFTIImporter
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.load import load_entity_by_gid
 from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
@@ -74,7 +73,6 @@ class TestNIFTIImporter(BaseTestCase):
         Clean-up tests data
         """
         self.clean_database()
-        FilesHelper().remove_project_structure(self.test_project.name)
 
     def _import(self, import_file_path=None, expected_result_class=StructuralMRIIndex, connectivity_gid=None):
         """
@@ -113,10 +111,7 @@ class TestNIFTIImporter(BaseTestCase):
         assert dimension_labels is not None
         assert 4 == len(json.loads(dimension_labels))
 
-        volume_index = load_entity_by_gid(time_series_index.fk_volume_gid)
-        assert volume_index is not None
-
-        volume = h5.load_from_index(volume_index)
+        volume = h5.load_from_gid(time_series_index.fk_volume_gid)
 
         assert numpy.equal(self.DEFAULT_ORIGIN, volume.origin).all()
         assert "mm" == volume.voxel_unit
@@ -136,10 +131,7 @@ class TestNIFTIImporter(BaseTestCase):
         assert 64 == data_shape[1]
         assert 10 == data_shape[2]
 
-        volume_index = load_entity_by_gid(structural_mri_index.fk_volume_gid)
-        assert volume_index is not None
-
-        volume = h5.load_from_index(volume_index)
+        volume = h5.load_from_gid(structural_mri_index.fk_volume_gid)
 
         assert numpy.equal(self.DEFAULT_ORIGIN, volume.origin).all()
         assert numpy.equal([3.0, 3.0, 3.0], volume.voxel_size).all()
@@ -167,10 +159,7 @@ class TestNIFTIImporter(BaseTestCase):
         assert mapping.array_data.max() < to_link_conn.number_of_regions
         assert to_link_conn.gid == mapping_index.fk_connectivity_gid
 
-        volume_index = load_entity_by_gid(mapping_index.fk_volume_gid)
-        assert volume_index is not None
-
-        volume = h5.load_from_index(volume_index)
+        volume = h5.load_from_gid(mapping_index.fk_volume_gid)
         assert numpy.equal(self.DEFAULT_ORIGIN, volume.origin).all()
         assert numpy.equal([3.0, 3.0, 3.0], volume.voxel_size).all()
         assert self.UNKNOWN_STR == volume.voxel_unit
