@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -39,10 +39,9 @@ import tvb_data.projectionMatrix as dataset
 import tvb_data.sensors
 import tvb_data.surfaceData
 from tvb.adapters.datatypes.db.projections import ProjectionMatrixIndex
-from tvb.adapters.uploaders.sensors_importer import SensorsImporterModel
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.services.exceptions import OperationException
-from tvb.datatypes.surfaces import CORTICAL
+from tvb.datatypes.sensors import SensorTypesEnum
+from tvb.datatypes.surfaces import SurfaceTypesEnum
 from tvb.tests.framework.core.base_testcase import BaseTestCase
 from tvb.tests.framework.core.factory import TestFactory
 
@@ -61,17 +60,17 @@ class TestProjectionMatrix(BaseTestCase):
 
         zip_path = os.path.join(os.path.dirname(tvb_data.sensors.__file__), 'eeg_brainstorm_65.txt')
         self.sensors = TestFactory.import_sensors(self.test_user, self.test_project, zip_path,
-                                                  SensorsImporterModel.OPTIONS['EEG Sensors'])
+                                                  SensorTypesEnum.TYPE_EEG)
 
         zip_path = os.path.join(os.path.dirname(tvb_data.surfaceData.__file__), 'cortex_16384.zip')
-        self.surface = TestFactory.import_surface_zip(self.test_user, self.test_project, zip_path, CORTICAL, True)
+        self.surface = TestFactory.import_surface_zip(self.test_user, self.test_project, zip_path,
+                                                      SurfaceTypesEnum.CORTICAL_SURFACE, True)
 
     def teardown_method(self):
         """
         Clean-up tests data
         """
         self.clean_database()
-        FilesHelper().remove_project_structure(self.test_project.name)
 
     def test_wrong_shape(self):
         """
