@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -32,17 +32,15 @@
 .. moduleauthor:: bogdan.neacsa <bogdan.neacsa@codemart.ro>
 """
 
-import json
 import pytest
-from tvb.core.entities.file.files_helper import FilesHelper
-from tvb.core.neocom import h5
 from tvb.core.entities.model.model_operation import Operation, STATUS_STARTED
 from tvb.core.entities.storage import dao
 from tvb.core.adapters.exceptions import NoMemoryAvailableException
 from tvb.core.services.operation_service import OperationService
+from tvb.storage.storage_interface import StorageInterface
 from tvb.tests.framework.core.base_testcase import TransactionalTestCase
 from tvb.tests.framework.core.factory import TestFactory
-from tvb.tests.framework.adapters.testadapter3 import *
+from tvb.tests.framework.adapters.dummy_adapter3 import *
 
 
 class TestAdapterMemoryUsage(TransactionalTestCase):
@@ -58,8 +56,8 @@ class TestAdapterMemoryUsage(TransactionalTestCase):
         self.test_project = TestFactory.create_project(admin=self.test_user)
 
     def test_adapter_memory(self, test_adapter_factory):
-        test_adapter_factory(adapter_class=TestAdapterHDDRequired)
-        adapter = TestFactory.create_adapter("tvb.tests.framework.adapters.testadapter3", "TestAdapterHDDRequired")
+        test_adapter_factory(adapter_class=DummyAdapterHDDRequired)
+        adapter = TestFactory.create_adapter("tvb.tests.framework.adapters.dummy_adapter3", "DummyAdapterHDDRequired")
         assert 42 == adapter.get_required_memory_size(adapter.get_view_model()())
 
     def test_adapter_huge_memory_requirement(self, test_adapter_factory):
@@ -67,13 +65,12 @@ class TestAdapterMemoryUsage(TransactionalTestCase):
         Test that an MemoryException is raised in case adapter cant launch due to lack of memory.
         """
         # Prepare adapter
-        test_adapter_factory(adapter_class=TestAdapterHugeMemoryRequired)
-        adapter = TestFactory.create_adapter("tvb.tests.framework.adapters.testadapter3",
-                                             "TestAdapterHugeMemoryRequired")
+        test_adapter_factory(adapter_class=DummyAdapterHugeMemoryRequired)
+        adapter = TestFactory.create_adapter("tvb.tests.framework.adapters.dummy_adapter3",
+                                             "DummyAdapterHugeMemoryRequired")
 
         # Simulate receiving POST data
-        form = TestAdapterHugeMemoryRequiredForm()
-        adapter.submit_form(form)
+        form = DummyAdapterHugeMemoryRequiredForm()
 
         view_model = form.get_view_model()()
         view_model.test = 5
@@ -84,7 +81,7 @@ class TestAdapterMemoryUsage(TransactionalTestCase):
         operation = dao.store_entity(operation)
 
         # Store ViewModel in H5
-        parent_folder = FilesHelper().get_project_folder(self.test_project, str(operation.id))
+        parent_folder = StorageInterface().get_project_folder(self.test_project.name, str(operation.id))
         h5.store_view_model(view_model, parent_folder)
 
         # Launch operation
