@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -34,11 +34,12 @@
 
 from os import path
 import tvb_data
+
 from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
+from tvb.adapters.forms.model_forms import ModelsEnum
 from tvb.core.services.burst_config_serialization import SerializationManager
 from tvb.simulator.simulator import Simulator
 from tvb.simulator.integrators import HeunStochastic
-from tvb.simulator.models import ModelsEnum
 from tvb.tests.framework.core.base_testcase import TransactionalTestCase
 from tvb.tests.framework.core.factory import TestFactory
 
@@ -52,7 +53,7 @@ class TestSerializationManager(TransactionalTestCase):
         TestFactory.import_zip_connectivity(self.test_user, self.test_project, zip_path, "John")
         self.connectivity = TestFactory.get_entity(self.test_project, ConnectivityIndex)
 
-        sim_conf = Simulator(model=ModelsEnum.HOPFIELD.get_class()(), integrator=HeunStochastic())
+        sim_conf = Simulator(model=ModelsEnum.HOPFIELD.instance, integrator=HeunStochastic())
 
         self.s_manager = SerializationManager(sim_conf)
         self.empty_manager = SerializationManager(None)
@@ -65,7 +66,7 @@ class TestSerializationManager(TransactionalTestCase):
 
     def test_write_model_parameters_one_dynamic(self, connectivity_factory):
         connectivity = connectivity_factory()
-        m_name = ModelsEnum.GENERIC_2D_OSCILLATOR.get_class().__name__
+        m_name = ModelsEnum.GENERIC_2D_OSCILLATOR.value.__name__
         m_parms = {'I': 0.0, 'a': 1.75, 'alpha': 1.0, 'b': -10.0, 'beta': 1.0, 'c': 0.0,
                    'd': 0.02, 'e': 3.0, 'f': 1.0, 'g': 0.0, 'gamma': 1.0, 'tau': 1.47}
 
@@ -73,7 +74,7 @@ class TestSerializationManager(TransactionalTestCase):
 
         sc = self.s_manager.conf
         # Default model in these tests is Hopfield. Test if the model was changed to Generic2dOscillator
-        assert isinstance(sc.model, ModelsEnum.GENERIC_2D_OSCILLATOR.get_class())
+        assert isinstance(sc.model, ModelsEnum.GENERIC_2D_OSCILLATOR.value)
 
         # a modified parameter
         expected = [1.75]  # we expect same value arrays to contract to 1 element
@@ -86,7 +87,7 @@ class TestSerializationManager(TransactionalTestCase):
 
     def test_write_model_parameters_two_dynamics(self, connectivity_factory):
         connectivity = connectivity_factory()
-        m_name = ModelsEnum.GENERIC_2D_OSCILLATOR.get_class().__name__
+        m_name = ModelsEnum.GENERIC_2D_OSCILLATOR.value.__name__
         m_parms_1 = {'I': 0.0, 'a': 1.75, 'alpha': 1.0, 'b': -10.0, 'beta': 1.0, 'c': 0.0,
                      'd': 0.02, 'e': 3.0, 'f': 1.0, 'g': 0.0, 'gamma': 1.0, 'tau': 1.47}
         m_parms_2 = {'I': 0.0, 'a': 1.75, 'alpha': 1.0, 'b': -5.0, 'beta': 1.0, 'c': 0.0,
@@ -99,7 +100,7 @@ class TestSerializationManager(TransactionalTestCase):
 
         sc = self.s_manager.conf
         # Default model in these tests is Hopfield. Test if the model was changed to Generic2dOscillator
-        assert isinstance(sc.model, ModelsEnum.GENERIC_2D_OSCILLATOR.get_class())
+        assert isinstance(sc.model, ModelsEnum.GENERIC_2D_OSCILLATOR.value)
 
         expected = [1.75]  # array contracted to one value
         actual = sc.model.a
