@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -128,7 +128,9 @@ class TestProjectController(BaseTransactionalControllerTest):
                     description="Some test descript.",
                     users=[],
                     administrator=self.test_user.username,
-                    visited_pages=None)
+                    visited_pages=None,
+                    max_operation_size=None,
+                    disable_imports=False)
         cherrypy.request.method = "POST"
         self._expect_redirect('/project/viewall', self.project_c.editone, save=True, **data)
         projects = dao.get_projects_for_user(self.test_user.id)
