@@ -44,22 +44,23 @@ from tvb.adapters.creators.stimulus_creator import RegionStimulusCreator
 from tvb.adapters.datatypes.db.patterns import StimuliRegionIndex
 from tvb.adapters.datatypes.db.simulation_history import SimulationHistoryIndex
 from tvb.adapters.datatypes.db.surface import SurfaceIndex
-from tvb.adapters.simulator.coupling_forms import get_form_for_coupling
-from tvb.adapters.simulator.equation_forms import TemporalEquationsEnum
-from tvb.adapters.simulator.model_forms import get_form_for_model, ModelsEnum
+from tvb.adapters.forms.coupling_forms import get_form_for_coupling, LinearCouplingForm
+from tvb.adapters.forms.equation_forms import TemporalEquationsEnum
+from tvb.adapters.forms.model_forms import get_form_for_model, ModelsEnum, Generic2dOscillatorModelForm
 from tvb.core.entities.file.simulator.view_model import *
 from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
 from tvb.core.services.burst_service import BurstService
 from tvb.core.services.operation_service import OperationService
-from tvb.datatypes.equations import FirstOrderVolterra, GeneralizedSigmoid, Linear
+from tvb.datatypes.equations import FirstOrderVolterra, Linear
 from tvb.datatypes.sensors import SensorTypesEnum
 from tvb.datatypes.surfaces import SurfaceTypesEnum
 from tvb.interfaces.web.controllers.common import *
-from tvb.interfaces.web.controllers.simulator.simulator_controller import SimulatorController
+from tvb.interfaces.web.controllers.simulator.simulator_controller import SimulatorController, FormWithRanges
 from tvb.simulator.coupling import Sigmoidal
 from tvb.simulator.monitors import DefaultMasks
+from tvb.simulator.simulator import Simulator
 from tvb.storage.storage_interface import StorageInterface
 from tvb.tests.framework.core.factory import TestFactory
 from tvb.tests.framework.interfaces.web.controllers.base_controller_test import BaseTransactionalControllerTest
@@ -894,13 +895,18 @@ class TestSimulationController(BaseTransactionalControllerTest):
         assert self.session_stored_simulator.simulation_length == 1000, "Incorrect simulation length!"
 
     def test_set_pse_params(self):
-        self.sess_mock['pse_param1'] = 'model.a'
-        self.sess_mock['pse_param2'] = 'model.c'
+        self.sess_mock['pse_param1'] = "model.:math:`a`"
+        self.sess_mock['pse_param2'] = "model.:math:`c`"
 
         self.simulator_controller.range_parameters.coupling_parameters = get_form_for_coupling(type(
-            self.session_stored_simulator.coupling))().get_range_parameters()
+            self.session_stored_simulator.coupling))().get_range_parameters(Simulator.coupling.field_name)
         self.simulator_controller.range_parameters.model_parameters = get_form_for_model(type(
-            self.session_stored_simulator.model))().get_range_parameters()
+            self.session_stored_simulator.model))().get_range_parameters(Simulator.model.field_name)
+
+        self.simulator_controller.range_parameters.range_param_forms[FormWithRanges.COUPLING_FRAGMENT_KEY] = \
+            LinearCouplingForm()
+        self.simulator_controller.range_parameters.range_param_forms[FormWithRanges.MODEL_FRAGMENT_KEY] = \
+            Generic2dOscillatorModelForm()
 
         burst_config = BurstConfiguration(self.test_project.id)
 
@@ -909,25 +915,30 @@ class TestSimulationController(BaseTransactionalControllerTest):
             self.simulator_controller.context.set_simulator(self.session_stored_simulator)
             rendering_rules = self.simulator_controller.set_pse_params(**self.sess_mock._data)
 
-        assert eval(burst_config.range1)[0] == 'model.a', "pse_param1 was not set correctly!"
-        assert eval(burst_config.range2)[0] == 'model.c', "pse_param2 was not set correctly!"
+        assert eval(burst_config.range1)[0] == 'model.:math:`a`', "pse_param1 was not set correctly!"
+        assert eval(burst_config.range2)[0] == 'model.:math:`c`', "pse_param2 was not set correctly!"
         assert rendering_rules['renderer'].include_launch_pse_button, 'Launch PSE button should be displayed!'
         assert not rendering_rules['renderer'].include_next_button, 'Next button should not be displayed!'
 
     def test_launch_pse(self):
-        self.sess_mock['pse_param1_name'] = 'model.a'
+        self.sess_mock['pse_param1_name'] = 'model.:math:`a`'
         self.sess_mock['pse_param1_lo'] = '-5.0'
         self.sess_mock['pse_param1_hi'] = '5.0'
         self.sess_mock['pse_param1_step'] = '5.0'
-        self.sess_mock['pse_param2_name'] = 'model.c'
+        self.sess_mock['pse_param2_name'] = 'model.:math:`c`'
         self.sess_mock['pse_param2_lo'] = '-10.0'
         self.sess_mock['pse_param2_hi'] = '10.0'
         self.sess_mock['pse_param2_step'] = '10.0'
 
         self.simulator_controller.range_parameters.coupling_parameters = get_form_for_coupling(type(
-            self.session_stored_simulator.coupling))().get_range_parameters()
+            self.session_stored_simulator.coupling))().get_range_parameters(Simulator.coupling.field_name)
         self.simulator_controller.range_parameters.model_parameters = get_form_for_model(type(
-            self.session_stored_simulator.model))().get_range_parameters()
+            self.session_stored_simulator.model))().get_range_parameters(Simulator.model.field_name)
+
+        self.simulator_controller.range_parameters.range_param_forms[FormWithRanges.COUPLING_FRAGMENT_KEY] = \
+            LinearCouplingForm()
+        self.simulator_controller.range_parameters.range_param_forms[FormWithRanges.MODEL_FRAGMENT_KEY] = \
+            Generic2dOscillatorModelForm()
 
         burst_config = BurstConfiguration(self.test_project.id)
 
